# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.topology_query_data_source import TopologyQueryDataSource


class TopologyQuery(ModelNormal):
    validations = {
        "filters": {
            "min_items": 1,
        },
    }

    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.topology_query_data_source import TopologyQueryDataSource

        return {
            "data_source": (TopologyQueryDataSource,),
            "filters": ([str],),
            "service": (str,),
        }

    attribute_map = {
        "data_source": "data_source",
        "filters": "filters",
        "service": "service",
    }

    def __init__(
        self_,
        data_source: Union[TopologyQueryDataSource, UnsetType] = unset,
        filters: Union[List[str], UnsetType] = unset,
        service: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Query to service-based topology data sources like the service map or data streams.

        :param data_source: Name of the data source
        :type data_source: TopologyQueryDataSource, optional

        :param filters: Your environment and primary tag (or * if enabled for your account).
        :type filters: [str], optional

        :param service: Name of the service
        :type service: str, optional
        """
        if data_source is not unset:
            kwargs["data_source"] = data_source
        if filters is not unset:
            kwargs["filters"] = filters
        if service is not unset:
            kwargs["service"] = service
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders


class SyntheticsTestRequestProxy(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_test_headers import SyntheticsTestHeaders

        return {
            "headers": (SyntheticsTestHeaders,),
            "url": (str,),
        }

    attribute_map = {
        "headers": "headers",
        "url": "url",
    }

    def __init__(self_, url: str, headers: Union[SyntheticsTestHeaders, UnsetType] = unset, **kwargs):
        """
        The proxy to perform the test.

        :param headers: Headers to include when performing the test.
        :type headers: SyntheticsTestHeaders, optional

        :param url: URL of the proxy to perform the test.
        :type url: str
        """
        if headers is not unset:
            kwargs["headers"] = headers
        super().__init__(kwargs)

        self_.url = url



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class MetricIntakeType(ModelSimple):
    """
    The type of metric. The available types are `0` (unspecified), `1` (count), `2` (rate), and `3` (gauge).

    :param value: Must be one of [0, 1, 2, 3].
    :type value: int
    """

    allowed_values = {
        0,
        1,
        2,
        3,
    }
    UNSPECIFIED: ClassVar["MetricIntakeType"]
    COUNT: ClassVar["MetricIntakeType"]
    RATE: ClassVar["MetricIntakeType"]
    GAUGE: ClassVar["MetricIntakeType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (int,),
        }


MetricIntakeType.UNSPECIFIED = MetricIntakeType(0)
MetricIntakeType.COUNT = MetricIntakeType(1)
MetricIntakeType.RATE = MetricIntakeType(2)
MetricIntakeType.GAUGE = MetricIntakeType(3)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class HTTPLogError(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "detail": (str,),
            "status": (str,),
            "title": (str,),
        }

    attribute_map = {
        "detail": "detail",
        "status": "status",
        "title": "title",
    }

    def __init__(
        self_,
        detail: Union[str, UnsetType] = unset,
        status: Union[str, UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        List of errors.

        :param detail: Error message.
        :type detail: str, optional

        :param status: Error code.
        :type status: str, optional

        :param title: Error title.
        :type title: str, optional
        """
        if detail is not unset:
            kwargs["detail"] = detail
        if status is not unset:
            kwargs["status"] = status
        if title is not unset:
            kwargs["title"] = title
        super().__init__(kwargs)



"""
Update host tags returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.tags_api import TagsApi
from datadog_api_client.v1.model.host_tags import HostTags

body = HostTags(
    host="test.host",
    tags=[
        "environment:production",
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = TagsApi(api_client)
    response = api_instance.update_host_tags(host_name="host_name", body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.confluent_account_response_attributes import ConfluentAccountResponseAttributes
    from datadog_api_client.v2.model.confluent_account_type import ConfluentAccountType


class ConfluentAccountResponseData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.confluent_account_response_attributes import ConfluentAccountResponseAttributes
        from datadog_api_client.v2.model.confluent_account_type import ConfluentAccountType

        return {
            "attributes": (ConfluentAccountResponseAttributes,),
            "id": (str,),
            "type": (ConfluentAccountType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "id": "id",
        "type": "type",
    }

    def __init__(self_, attributes: ConfluentAccountResponseAttributes, id: str, type: ConfluentAccountType, **kwargs):
        """
        An API key and API secret pair that represents a Confluent account.

        :param attributes: The attributes of a Confluent account.
        :type attributes: ConfluentAccountResponseAttributes

        :param id: A randomly generated ID associated with a Confluent account.
        :type id: str

        :param type: The JSON:API type for this API. Should always be ``confluent-cloud-accounts``.
        :type type: ConfluentAccountType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.id = id
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.incident_attachment_link_attributes_attachment_object import (
        IncidentAttachmentLinkAttributesAttachmentObject,
    )
    from datadog_api_client.v2.model.incident_attachment_link_attachment_type import (
        IncidentAttachmentLinkAttachmentType,
    )


class IncidentAttachmentLinkAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.incident_attachment_link_attributes_attachment_object import (
            IncidentAttachmentLinkAttributesAttachmentObject,
        )
        from datadog_api_client.v2.model.incident_attachment_link_attachment_type import (
            IncidentAttachmentLinkAttachmentType,
        )

        return {
            "attachment": (IncidentAttachmentLinkAttributesAttachmentObject,),
            "attachment_type": (IncidentAttachmentLinkAttachmentType,),
        }

    attribute_map = {
        "attachment": "attachment",
        "attachment_type": "attachment_type",
    }

    def __init__(
        self_,
        attachment: IncidentAttachmentLinkAttributesAttachmentObject,
        attachment_type: IncidentAttachmentLinkAttachmentType,
        **kwargs,
    ):
        """
        The attributes object for a link attachment.

        :param attachment: The link attachment.
        :type attachment: IncidentAttachmentLinkAttributesAttachmentObject

        :param attachment_type: The type of link attachment attributes.
        :type attachment_type: IncidentAttachmentLinkAttachmentType
        """
        super().__init__(kwargs)

        self_.attachment = attachment
        self_.attachment_type = attachment_type



"""
Create a metric monitor returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.monitors_api import MonitorsApi
from datadog_api_client.v1.model.monitor import Monitor
from datadog_api_client.v1.model.monitor_options import MonitorOptions
from datadog_api_client.v1.model.monitor_options_scheduling_options import MonitorOptionsSchedulingOptions
from datadog_api_client.v1.model.monitor_options_scheduling_options_evaluation_window import (
    MonitorOptionsSchedulingOptionsEvaluationWindow,
)
from datadog_api_client.v1.model.monitor_thresholds import MonitorThresholds
from datadog_api_client.v1.model.monitor_type import MonitorType

body = Monitor(
    name="Example-Create_a_metric_monitor_returns_OK_response",
    type=MonitorType.METRIC_ALERT,
    query="avg(current_1d):avg:system.load.5{*} > 0.5",
    message="some message Notify: @hipchat-channel",
    options=MonitorOptions(
        thresholds=MonitorThresholds(
            critical=0.5,
        ),
        scheduling_options=MonitorOptionsSchedulingOptions(
            evaluation_window=MonitorOptionsSchedulingOptionsEvaluationWindow(
                day_starts="04:00",
                month_starts=1,
            ),
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MonitorsApi(api_client)
    response = api_instance.create_monitor(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


class CIAppAggregateBucketValueTimeseriesPoint(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "time": (datetime,),
            "value": (float,),
        }

    attribute_map = {
        "time": "time",
        "value": "value",
    }

    def __init__(self_, time: Union[datetime, UnsetType] = unset, value: Union[float, UnsetType] = unset, **kwargs):
        """
        A timeseries point.

        :param time: The time value for this point.
        :type time: datetime, optional

        :param value: The value for this point.
        :type value: float, optional
        """
        if time is not unset:
            kwargs["time"] = time
        if value is not unset:
            kwargs["value"] = value
        super().__init__(kwargs)



"""
Edit an API key returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.key_management_api import KeyManagementApi
from datadog_api_client.v1.model.api_key import ApiKey

body = ApiKey(
    name="example user",
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    response = api_instance.update_api_key(key="key", body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.metric_custom_aggregations import MetricCustomAggregations
    from datadog_api_client.v2.model.metric_tag_configuration_metric_types import MetricTagConfigurationMetricTypes


class MetricTagConfigurationCreateAttributes(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.metric_custom_aggregations import MetricCustomAggregations
        from datadog_api_client.v2.model.metric_tag_configuration_metric_types import MetricTagConfigurationMetricTypes

        return {
            "aggregations": (MetricCustomAggregations,),
            "include_percentiles": (bool,),
            "metric_type": (MetricTagConfigurationMetricTypes,),
            "tags": ([str],),
        }

    attribute_map = {
        "aggregations": "aggregations",
        "include_percentiles": "include_percentiles",
        "metric_type": "metric_type",
        "tags": "tags",
    }

    def __init__(
        self_,
        metric_type: MetricTagConfigurationMetricTypes,
        aggregations: Union[MetricCustomAggregations, UnsetType] = unset,
        include_percentiles: Union[bool, UnsetType] = unset,
        **kwargs,
    ):
        """
        Object containing the definition of a metric tag configuration to be created.

        :param aggregations: A list of queryable aggregation combinations for a count, rate, or gauge metric.
            By default, count and rate metrics require the (time: sum, space: sum) aggregation and
            Gauge metrics require the (time: avg, space: avg) aggregation.
            Additional time & space combinations are also available:

            * time: avg, space: avg
            * time: avg, space: max
            * time: avg, space: min
            * time: avg, space: sum
            * time: count, space: sum
            * time: max, space: max
            * time: min, space: min
            * time: sum, space: avg
            * time: sum, space: sum

            Can only be applied to metrics that have a ``metric_type`` of ``count`` , ``rate`` , or ``gauge``.
        :type aggregations: MetricCustomAggregations, optional

        :param include_percentiles: Toggle to include/exclude percentiles for a distribution metric.
            Defaults to false. Can only be applied to metrics that have a ``metric_type`` of ``distribution``.
        :type include_percentiles: bool, optional

        :param metric_type: The metric's type.
        :type metric_type: MetricTagConfigurationMetricTypes

        :param tags: A list of tag keys that will be queryable for your metric.
        :type tags: [str]
        """
        if aggregations is not unset:
            kwargs["aggregations"] = aggregations
        if include_percentiles is not unset:
            kwargs["include_percentiles"] = include_percentiles
        super().__init__(kwargs)
        tags = kwargs.get("tags", [])

        self_.metric_type = metric_type
        self_.tags = tags



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SyntheticsCoreWebVitals(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "_cls": (float,),
            "lcp": (float,),
            "url": (str,),
        }

    attribute_map = {
        "_cls": "cls",
        "lcp": "lcp",
        "url": "url",
    }

    def __init__(
        self_,
        _cls: Union[float, UnsetType] = unset,
        lcp: Union[float, UnsetType] = unset,
        url: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Core Web Vitals attached to a browser test step.

        :param _cls: Cumulative Layout Shift.
        :type _cls: float, optional

        :param lcp: Largest Contentful Paint in milliseconds.
        :type lcp: float, optional

        :param url: URL attached to the metrics.
        :type url: str, optional
        """
        if _cls is not unset:
            kwargs["_cls"] = _cls
        if lcp is not unset:
            kwargs["lcp"] = lcp
        if url is not unset:
            kwargs["url"] = url
        super().__init__(kwargs)



"""
Create an application key for this service account returns "Created" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.service_accounts_api import ServiceAccountsApi
from datadog_api_client.v2.model.application_key_create_attributes import ApplicationKeyCreateAttributes
from datadog_api_client.v2.model.application_key_create_data import ApplicationKeyCreateData
from datadog_api_client.v2.model.application_key_create_request import ApplicationKeyCreateRequest
from datadog_api_client.v2.model.application_keys_type import ApplicationKeysType

body = ApplicationKeyCreateRequest(
    data=ApplicationKeyCreateData(
        attributes=ApplicationKeyCreateAttributes(
            name="Application Key for managing dashboards",
            scopes=[
                "dashboards_read",
                "dashboards_write",
                "dashboards_public_share",
            ],
        ),
        type=ApplicationKeysType.APPLICATION_KEYS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = ServiceAccountsApi(api_client)
    response = api_instance.create_service_account_application_key(
        service_account_id="00000000-0000-1234-0000-000000000000", body=body
    )

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class SyntheticsDeleteTestsPayload(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "public_ids": ([str],),
        }

    attribute_map = {
        "public_ids": "public_ids",
    }

    def __init__(self_, public_ids: Union[List[str], UnsetType] = unset, **kwargs):
        """
        A JSON list of the ID or IDs of the Synthetic tests that you want
        to delete.

        :param public_ids: An array of Synthetic test IDs you want to delete.
        :type public_ids: [str], optional
        """
        if public_ids is not unset:
            kwargs["public_ids"] = public_ids
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.synthetics_assertion_x_path_operator import SyntheticsAssertionXPathOperator
    from datadog_api_client.v1.model.synthetics_assertion_x_path_target_target import (
        SyntheticsAssertionXPathTargetTarget,
    )
    from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType


class SyntheticsAssertionXPathTarget(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.synthetics_assertion_x_path_operator import SyntheticsAssertionXPathOperator
        from datadog_api_client.v1.model.synthetics_assertion_x_path_target_target import (
            SyntheticsAssertionXPathTargetTarget,
        )
        from datadog_api_client.v1.model.synthetics_assertion_type import SyntheticsAssertionType

        return {
            "operator": (SyntheticsAssertionXPathOperator,),
            "_property": (str,),
            "target": (SyntheticsAssertionXPathTargetTarget,),
            "type": (SyntheticsAssertionType,),
        }

    attribute_map = {
        "operator": "operator",
        "_property": "property",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        operator: SyntheticsAssertionXPathOperator,
        type: SyntheticsAssertionType,
        _property: Union[str, UnsetType] = unset,
        target: Union[SyntheticsAssertionXPathTargetTarget, UnsetType] = unset,
        **kwargs,
    ):
        """
        An assertion for the ``validatesXPath`` operator.

        :param operator: Assertion operator to apply.
        :type operator: SyntheticsAssertionXPathOperator

        :param _property: The associated assertion property.
        :type _property: str, optional

        :param target: Composed target for ``validatesXPath`` operator.
        :type target: SyntheticsAssertionXPathTargetTarget, optional

        :param type: Type of the assertion.
        :type type: SyntheticsAssertionType
        """
        if _property is not unset:
            kwargs["_property"] = _property
        if target is not unset:
            kwargs["target"] = target
        super().__init__(kwargs)

        self_.operator = operator
        self_.type = type



"""
Edit a browser test returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.synthetics_api import SyntheticsApi
from datadog_api_client.v1.model.synthetics_basic_auth_web import SyntheticsBasicAuthWeb
from datadog_api_client.v1.model.synthetics_basic_auth_web_type import SyntheticsBasicAuthWebType
from datadog_api_client.v1.model.synthetics_browser_test import SyntheticsBrowserTest
from datadog_api_client.v1.model.synthetics_browser_test_config import SyntheticsBrowserTestConfig
from datadog_api_client.v1.model.synthetics_browser_test_rum_settings import SyntheticsBrowserTestRumSettings
from datadog_api_client.v1.model.synthetics_browser_test_type import SyntheticsBrowserTestType
from datadog_api_client.v1.model.synthetics_browser_variable import SyntheticsBrowserVariable
from datadog_api_client.v1.model.synthetics_browser_variable_type import SyntheticsBrowserVariableType
from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
from datadog_api_client.v1.model.synthetics_config_variable_type import SyntheticsConfigVariableType
from datadog_api_client.v1.model.synthetics_device_id import SyntheticsDeviceID
from datadog_api_client.v1.model.synthetics_restricted_roles import SyntheticsRestrictedRoles
from datadog_api_client.v1.model.synthetics_step import SyntheticsStep
from datadog_api_client.v1.model.synthetics_step_type import SyntheticsStepType
from datadog_api_client.v1.model.synthetics_test_call_type import SyntheticsTestCallType
from datadog_api_client.v1.model.synthetics_test_ci_options import SyntheticsTestCiOptions
from datadog_api_client.v1.model.synthetics_test_execution_rule import SyntheticsTestExecutionRule
from datadog_api_client.v1.model.synthetics_test_options import SyntheticsTestOptions
from datadog_api_client.v1.model.synthetics_test_options_monitor_options import SyntheticsTestOptionsMonitorOptions
from datadog_api_client.v1.model.synthetics_test_options_retry import SyntheticsTestOptionsRetry
from datadog_api_client.v1.model.synthetics_test_pause_status import SyntheticsTestPauseStatus
from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
from datadog_api_client.v1.model.synthetics_test_request_body_type import SyntheticsTestRequestBodyType
from datadog_api_client.v1.model.synthetics_test_request_certificate import SyntheticsTestRequestCertificate
from datadog_api_client.v1.model.synthetics_test_request_certificate_item import SyntheticsTestRequestCertificateItem
from datadog_api_client.v1.model.synthetics_test_request_proxy import SyntheticsTestRequestProxy

body = SyntheticsBrowserTest(
    config=SyntheticsBrowserTestConfig(
        assertions=[],
        config_variables=[
            SyntheticsConfigVariable(
                name="VARIABLE_NAME",
                secure=False,
                type=SyntheticsConfigVariableType.TEXT,
            ),
        ],
        request=SyntheticsTestRequest(
            basic_auth=SyntheticsBasicAuthWeb(
                password="PaSSw0RD!",
                type=SyntheticsBasicAuthWebType.WEB,
                username="my_username",
            ),
            body_type=SyntheticsTestRequestBodyType.TEXT_PLAIN,
            call_type=SyntheticsTestCallType.UNARY,
            certificate=SyntheticsTestRequestCertificate(
                cert=SyntheticsTestRequestCertificateItem(),
                key=SyntheticsTestRequestCertificateItem(),
            ),
            certificate_domains=[],
            proxy=SyntheticsTestRequestProxy(
                url="https://example.com",
            ),
            service="Greeter",
            url="https://example.com",
        ),
        variables=[
            SyntheticsBrowserVariable(
                name="VARIABLE_NAME",
                type=SyntheticsBrowserVariableType.TEXT,
            ),
        ],
    ),
    locations=[
        "aws:eu-west-3",
    ],
    message="",
    name="Example test name",
    options=SyntheticsTestOptions(
        ci=SyntheticsTestCiOptions(
            execution_rule=SyntheticsTestExecutionRule.BLOCKING,
        ),
        device_ids=[
            SyntheticsDeviceID.LAPTOP_LARGE,
        ],
        monitor_options=SyntheticsTestOptionsMonitorOptions(),
        restricted_roles=SyntheticsRestrictedRoles(
            [
                "xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            ]
        ),
        retry=SyntheticsTestOptionsRetry(),
        rum_settings=SyntheticsBrowserTestRumSettings(
            application_id="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx",
            client_token_id=12345,
            is_enabled=True,
        ),
    ),
    status=SyntheticsTestPauseStatus.LIVE,
    steps=[
        SyntheticsStep(
            type=SyntheticsStepType.ASSERT_ELEMENT_CONTENT,
        ),
    ],
    tags=[
        "env:prod",
    ],
    type=SyntheticsBrowserTestType.BROWSER,
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = SyntheticsApi(api_client)
    response = api_instance.update_browser_test(public_id="public_id", body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    datetime,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_by_retention import LogsByRetention
    from datadog_api_client.v1.model.usage_summary_date import UsageSummaryDate


class UsageSummaryResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_by_retention import LogsByRetention
        from datadog_api_client.v1.model.usage_summary_date import UsageSummaryDate

        return {
            "agent_host_top99p_sum": (int,),
            "apm_azure_app_service_host_top99p_sum": (int,),
            "apm_fargate_count_avg_sum": (int,),
            "apm_host_top99p_sum": (int,),
            "appsec_fargate_count_avg_sum": (int,),
            "audit_logs_lines_indexed_agg_sum": (int,),
            "avg_profiled_fargate_tasks_sum": (int,),
            "aws_host_top99p_sum": (int,),
            "aws_lambda_func_count": (int,),
            "aws_lambda_invocations_sum": (int,),
            "azure_app_service_top99p_sum": (int,),
            "azure_host_top99p_sum": (int,),
            "billable_ingested_bytes_agg_sum": (int,),
            "browser_rum_lite_session_count_agg_sum": (int,),
            "browser_rum_replay_session_count_agg_sum": (int,),
            "browser_rum_units_agg_sum": (int,),
            "ci_pipeline_indexed_spans_agg_sum": (int,),
            "ci_test_indexed_spans_agg_sum": (int,),
            "ci_visibility_pipeline_committers_hwm_sum": (int,),
            "ci_visibility_test_committers_hwm_sum": (int,),
            "container_avg_sum": (int,),
            "container_hwm_sum": (int,),
            "cspm_aas_host_top99p_sum": (int,),
            "cspm_aws_host_top99p_sum": (int,),
            "cspm_azure_host_top99p_sum": (int,),
            "cspm_container_avg_sum": (int,),
            "cspm_container_hwm_sum": (int,),
            "cspm_gcp_host_top99p_sum": (int,),
            "cspm_host_top99p_sum": (int,),
            "custom_ts_sum": (int,),
            "cws_containers_avg_sum": (int,),
            "cws_host_top99p_sum": (int,),
            "dbm_host_top99p_sum": (int,),
            "dbm_queries_avg_sum": (int,),
            "end_date": (datetime,),
            "fargate_tasks_count_avg_sum": (int,),
            "fargate_tasks_count_hwm_sum": (int,),
            "gcp_host_top99p_sum": (int,),
            "heroku_host_top99p_sum": (int,),
            "incident_management_monthly_active_users_hwm_sum": (int,),
            "indexed_events_count_agg_sum": (int,),
            "infra_host_top99p_sum": (int,),
            "ingested_events_bytes_agg_sum": (int,),
            "iot_device_agg_sum": (int,),
            "iot_device_top99p_sum": (int,),
            "last_updated": (datetime,),
            "live_indexed_events_agg_sum": (int,),
            "live_ingested_bytes_agg_sum": (int,),
            "logs_by_retention": (LogsByRetention,),
            "mobile_rum_lite_session_count_agg_sum": (int,),
            "mobile_rum_session_count_agg_sum": (int,),
            "mobile_rum_session_count_android_agg_sum": (int,),
            "mobile_rum_session_count_ios_agg_sum": (int,),
            "mobile_rum_session_count_reactnative_agg_sum": (int,),
            "mobile_rum_units_agg_sum": (int,),
            "netflow_indexed_events_count_agg_sum": (int,),
            "npm_host_top99p_sum": (int,),
            "observability_pipelines_bytes_processed_agg_sum": (int,),
            "online_archive_events_count_agg_sum": (int,),
            "opentelemetry_apm_host_top99p_sum": (int,),
            "opentelemetry_host_top99p_sum": (int,),
            "profiling_container_agent_count_avg": (int,),
            "profiling_host_count_top99p_sum": (int,),
            "rehydrated_indexed_events_agg_sum": (int,),
            "rehydrated_ingested_bytes_agg_sum": (int,),
            "rum_browser_and_mobile_session_count": (int,),
            "rum_session_count_agg_sum": (int,),
            "rum_total_session_count_agg_sum": (int,),
            "rum_units_agg_sum": (int,),
            "sds_apm_scanned_bytes_sum": (int,),
            "sds_events_scanned_bytes_sum": (int,),
            "sds_logs_scanned_bytes_sum": (int,),
            "sds_rum_scanned_bytes_sum": (int,),
            "sds_total_scanned_bytes_sum": (int,),
            "start_date": (datetime,),
            "synthetics_browser_check_calls_count_agg_sum": (int,),
            "synthetics_check_calls_count_agg_sum": (int,),
            "synthetics_parallel_testing_max_slots_hwm_sum": (int,),
            "trace_search_indexed_events_count_agg_sum": (int,),
            "twol_ingested_events_bytes_agg_sum": (int,),
            "usage": ([UsageSummaryDate],),
            "vsphere_host_top99p_sum": (int,),
        }

    attribute_map = {
        "agent_host_top99p_sum": "agent_host_top99p_sum",
        "apm_azure_app_service_host_top99p_sum": "apm_azure_app_service_host_top99p_sum",
        "apm_fargate_count_avg_sum": "apm_fargate_count_avg_sum",
        "apm_host_top99p_sum": "apm_host_top99p_sum",
        "appsec_fargate_count_avg_sum": "appsec_fargate_count_avg_sum",
        "audit_logs_lines_indexed_agg_sum": "audit_logs_lines_indexed_agg_sum",
        "avg_profiled_fargate_tasks_sum": "avg_profiled_fargate_tasks_sum",
        "aws_host_top99p_sum": "aws_host_top99p_sum",
        "aws_lambda_func_count": "aws_lambda_func_count",
        "aws_lambda_invocations_sum": "aws_lambda_invocations_sum",
        "azure_app_service_top99p_sum": "azure_app_service_top99p_sum",
        "azure_host_top99p_sum": "azure_host_top99p_sum",
        "billable_ingested_bytes_agg_sum": "billable_ingested_bytes_agg_sum",
        "browser_rum_lite_session_count_agg_sum": "browser_rum_lite_session_count_agg_sum",
        "browser_rum_replay_session_count_agg_sum": "browser_rum_replay_session_count_agg_sum",
        "browser_rum_units_agg_sum": "browser_rum_units_agg_sum",
        "ci_pipeline_indexed_spans_agg_sum": "ci_pipeline_indexed_spans_agg_sum",
        "ci_test_indexed_spans_agg_sum": "ci_test_indexed_spans_agg_sum",
        "ci_visibility_pipeline_committers_hwm_sum": "ci_visibility_pipeline_committers_hwm_sum",
        "ci_visibility_test_committers_hwm_sum": "ci_visibility_test_committers_hwm_sum",
        "container_avg_sum": "container_avg_sum",
        "container_hwm_sum": "container_hwm_sum",
        "cspm_aas_host_top99p_sum": "cspm_aas_host_top99p_sum",
        "cspm_aws_host_top99p_sum": "cspm_aws_host_top99p_sum",
        "cspm_azure_host_top99p_sum": "cspm_azure_host_top99p_sum",
        "cspm_container_avg_sum": "cspm_container_avg_sum",
        "cspm_container_hwm_sum": "cspm_container_hwm_sum",
        "cspm_gcp_host_top99p_sum": "cspm_gcp_host_top99p_sum",
        "cspm_host_top99p_sum": "cspm_host_top99p_sum",
        "custom_ts_sum": "custom_ts_sum",
        "cws_containers_avg_sum": "cws_containers_avg_sum",
        "cws_host_top99p_sum": "cws_host_top99p_sum",
        "dbm_host_top99p_sum": "dbm_host_top99p_sum",
        "dbm_queries_avg_sum": "dbm_queries_avg_sum",
        "end_date": "end_date",
        "fargate_tasks_count_avg_sum": "fargate_tasks_count_avg_sum",
        "fargate_tasks_count_hwm_sum": "fargate_tasks_count_hwm_sum",
        "gcp_host_top99p_sum": "gcp_host_top99p_sum",
        "heroku_host_top99p_sum": "heroku_host_top99p_sum",
        "incident_management_monthly_active_users_hwm_sum": "incident_management_monthly_active_users_hwm_sum",
        "indexed_events_count_agg_sum": "indexed_events_count_agg_sum",
        "infra_host_top99p_sum": "infra_host_top99p_sum",
        "ingested_events_bytes_agg_sum": "ingested_events_bytes_agg_sum",
        "iot_device_agg_sum": "iot_device_agg_sum",
        "iot_device_top99p_sum": "iot_device_top99p_sum",
        "last_updated": "last_updated",
        "live_indexed_events_agg_sum": "live_indexed_events_agg_sum",
        "live_ingested_bytes_agg_sum": "live_ingested_bytes_agg_sum",
        "logs_by_retention": "logs_by_retention",
        "mobile_rum_lite_session_count_agg_sum": "mobile_rum_lite_session_count_agg_sum",
        "mobile_rum_session_count_agg_sum": "mobile_rum_session_count_agg_sum",
        "mobile_rum_session_count_android_agg_sum": "mobile_rum_session_count_android_agg_sum",
        "mobile_rum_session_count_ios_agg_sum": "mobile_rum_session_count_ios_agg_sum",
        "mobile_rum_session_count_reactnative_agg_sum": "mobile_rum_session_count_reactnative_agg_sum",
        "mobile_rum_units_agg_sum": "mobile_rum_units_agg_sum",
        "netflow_indexed_events_count_agg_sum": "netflow_indexed_events_count_agg_sum",
        "npm_host_top99p_sum": "npm_host_top99p_sum",
        "observability_pipelines_bytes_processed_agg_sum": "observability_pipelines_bytes_processed_agg_sum",
        "online_archive_events_count_agg_sum": "online_archive_events_count_agg_sum",
        "opentelemetry_apm_host_top99p_sum": "opentelemetry_apm_host_top99p_sum",
        "opentelemetry_host_top99p_sum": "opentelemetry_host_top99p_sum",
        "profiling_container_agent_count_avg": "profiling_container_agent_count_avg",
        "profiling_host_count_top99p_sum": "profiling_host_count_top99p_sum",
        "rehydrated_indexed_events_agg_sum": "rehydrated_indexed_events_agg_sum",
        "rehydrated_ingested_bytes_agg_sum": "rehydrated_ingested_bytes_agg_sum",
        "rum_browser_and_mobile_session_count": "rum_browser_and_mobile_session_count",
        "rum_session_count_agg_sum": "rum_session_count_agg_sum",
        "rum_total_session_count_agg_sum": "rum_total_session_count_agg_sum",
        "rum_units_agg_sum": "rum_units_agg_sum",
        "sds_apm_scanned_bytes_sum": "sds_apm_scanned_bytes_sum",
        "sds_events_scanned_bytes_sum": "sds_events_scanned_bytes_sum",
        "sds_logs_scanned_bytes_sum": "sds_logs_scanned_bytes_sum",
        "sds_rum_scanned_bytes_sum": "sds_rum_scanned_bytes_sum",
        "sds_total_scanned_bytes_sum": "sds_total_scanned_bytes_sum",
        "start_date": "start_date",
        "synthetics_browser_check_calls_count_agg_sum": "synthetics_browser_check_calls_count_agg_sum",
        "synthetics_check_calls_count_agg_sum": "synthetics_check_calls_count_agg_sum",
        "synthetics_parallel_testing_max_slots_hwm_sum": "synthetics_parallel_testing_max_slots_hwm_sum",
        "trace_search_indexed_events_count_agg_sum": "trace_search_indexed_events_count_agg_sum",
        "twol_ingested_events_bytes_agg_sum": "twol_ingested_events_bytes_agg_sum",
        "usage": "usage",
        "vsphere_host_top99p_sum": "vsphere_host_top99p_sum",
    }

    def __init__(
        self_,
        agent_host_top99p_sum: Union[int, UnsetType] = unset,
        apm_azure_app_service_host_top99p_sum: Union[int, UnsetType] = unset,
        apm_fargate_count_avg_sum: Union[int, UnsetType] = unset,
        apm_host_top99p_sum: Union[int, UnsetType] = unset,
        appsec_fargate_count_avg_sum: Union[int, UnsetType] = unset,
        audit_logs_lines_indexed_agg_sum: Union[int, UnsetType] = unset,
        avg_profiled_fargate_tasks_sum: Union[int, UnsetType] = unset,
        aws_host_top99p_sum: Union[int, UnsetType] = unset,
        aws_lambda_func_count: Union[int, UnsetType] = unset,
        aws_lambda_invocations_sum: Union[int, UnsetType] = unset,
        azure_app_service_top99p_sum: Union[int, UnsetType] = unset,
        azure_host_top99p_sum: Union[int, UnsetType] = unset,
        billable_ingested_bytes_agg_sum: Union[int, UnsetType] = unset,
        browser_rum_lite_session_count_agg_sum: Union[int, UnsetType] = unset,
        browser_rum_replay_session_count_agg_sum: Union[int, UnsetType] = unset,
        browser_rum_units_agg_sum: Union[int, UnsetType] = unset,
        ci_pipeline_indexed_spans_agg_sum: Union[int, UnsetType] = unset,
        ci_test_indexed_spans_agg_sum: Union[int, UnsetType] = unset,
        ci_visibility_pipeline_committers_hwm_sum: Union[int, UnsetType] = unset,
        ci_visibility_test_committers_hwm_sum: Union[int, UnsetType] = unset,
        container_avg_sum: Union[int, UnsetType] = unset,
        container_hwm_sum: Union[int, UnsetType] = unset,
        cspm_aas_host_top99p_sum: Union[int, UnsetType] = unset,
        cspm_aws_host_top99p_sum: Union[int, UnsetType] = unset,
        cspm_azure_host_top99p_sum: Union[int, UnsetType] = unset,
        cspm_container_avg_sum: Union[int, UnsetType] = unset,
        cspm_container_hwm_sum: Union[int, UnsetType] = unset,
        cspm_gcp_host_top99p_sum: Union[int, UnsetType] = unset,
        cspm_host_top99p_sum: Union[int, UnsetType] = unset,
        custom_ts_sum: Union[int, UnsetType] = unset,
        cws_containers_avg_sum: Union[int, UnsetType] = unset,
        cws_host_top99p_sum: Union[int, UnsetType] = unset,
        dbm_host_top99p_sum: Union[int, UnsetType] = unset,
        dbm_queries_avg_sum: Union[int, UnsetType] = unset,
        end_date: Union[datetime, UnsetType] = unset,
        fargate_tasks_count_avg_sum: Union[int, UnsetType] = unset,
        fargate_tasks_count_hwm_sum: Union[int, UnsetType] = unset,
        gcp_host_top99p_sum: Union[int, UnsetType] = unset,
        heroku_host_top99p_sum: Union[int, UnsetType] = unset,
        incident_management_monthly_active_users_hwm_sum: Union[int, UnsetType] = unset,
        indexed_events_count_agg_sum: Union[int, UnsetType] = unset,
        infra_host_top99p_sum: Union[int, UnsetType] = unset,
        ingested_events_bytes_agg_sum: Union[int, UnsetType] = unset,
        iot_device_agg_sum: Union[int, UnsetType] = unset,
        iot_device_top99p_sum: Union[int, UnsetType] = unset,
        last_updated: Union[datetime, UnsetType] = unset,
        live_indexed_events_agg_sum: Union[int, UnsetType] = unset,
        live_ingested_bytes_agg_sum: Union[int, UnsetType] = unset,
        logs_by_retention: Union[LogsByRetention, UnsetType] = unset,
        mobile_rum_lite_session_count_agg_sum: Union[int, UnsetType] = unset,
        mobile_rum_session_count_agg_sum: Union[int, UnsetType] = unset,
        mobile_rum_session_count_android_agg_sum: Union[int, UnsetType] = unset,
        mobile_rum_session_count_ios_agg_sum: Union[int, UnsetType] = unset,
        mobile_rum_session_count_reactnative_agg_sum: Union[int, UnsetType] = unset,
        mobile_rum_units_agg_sum: Union[int, UnsetType] = unset,
        netflow_indexed_events_count_agg_sum: Union[int, UnsetType] = unset,
        npm_host_top99p_sum: Union[int, UnsetType] = unset,
        observability_pipelines_bytes_processed_agg_sum: Union[int, UnsetType] = unset,
        online_archive_events_count_agg_sum: Union[int, UnsetType] = unset,
        opentelemetry_apm_host_top99p_sum: Union[int, UnsetType] = unset,
        opentelemetry_host_top99p_sum: Union[int, UnsetType] = unset,
        profiling_container_agent_count_avg: Union[int, UnsetType] = unset,
        profiling_host_count_top99p_sum: Union[int, UnsetType] = unset,
        rehydrated_indexed_events_agg_sum: Union[int, UnsetType] = unset,
        rehydrated_ingested_bytes_agg_sum: Union[int, UnsetType] = unset,
        rum_browser_and_mobile_session_count: Union[int, UnsetType] = unset,
        rum_session_count_agg_sum: Union[int, UnsetType] = unset,
        rum_total_session_count_agg_sum: Union[int, UnsetType] = unset,
        rum_units_agg_sum: Union[int, UnsetType] = unset,
        sds_apm_scanned_bytes_sum: Union[int, UnsetType] = unset,
        sds_events_scanned_bytes_sum: Union[int, UnsetType] = unset,
        sds_logs_scanned_bytes_sum: Union[int, UnsetType] = unset,
        sds_rum_scanned_bytes_sum: Union[int, UnsetType] = unset,
        sds_total_scanned_bytes_sum: Union[int, UnsetType] = unset,
        start_date: Union[datetime, UnsetType] = unset,
        synthetics_browser_check_calls_count_agg_sum: Union[int, UnsetType] = unset,
        synthetics_check_calls_count_agg_sum: Union[int, UnsetType] = unset,
        synthetics_parallel_testing_max_slots_hwm_sum: Union[int, UnsetType] = unset,
        trace_search_indexed_events_count_agg_sum: Union[int, UnsetType] = unset,
        twol_ingested_events_bytes_agg_sum: Union[int, UnsetType] = unset,
        usage: Union[List[UsageSummaryDate], UnsetType] = unset,
        vsphere_host_top99p_sum: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Response summarizing all usage aggregated across the months in the request for all organizations, and broken down by month and by organization.

        :param agent_host_top99p_sum: Shows the 99th percentile of all agent hosts over all hours in the current months for all organizations.
        :type agent_host_top99p_sum: int, optional

        :param apm_azure_app_service_host_top99p_sum: Shows the 99th percentile of all Azure app services using APM over all hours in the current months all organizations.
        :type apm_azure_app_service_host_top99p_sum: int, optional

        :param apm_fargate_count_avg_sum: Shows the average of all APM ECS Fargate tasks over all hours in the current months for all organizations.
        :type apm_fargate_count_avg_sum: int, optional

        :param apm_host_top99p_sum: Shows the 99th percentile of all distinct APM hosts over all hours in the current months for all organizations.
        :type apm_host_top99p_sum: int, optional

        :param appsec_fargate_count_avg_sum: Shows the average of all Application Security Monitoring ECS Fargate tasks over all hours in the current months for all organizations.
        :type appsec_fargate_count_avg_sum: int, optional

        :param audit_logs_lines_indexed_agg_sum: Shows the sum of all audit logs lines indexed over all hours in the current months for all organizations.
        :type audit_logs_lines_indexed_agg_sum: int, optional

        :param avg_profiled_fargate_tasks_sum: Shows the average of all profiled Fargate tasks over all hours in the current months for all organizations.
        :type avg_profiled_fargate_tasks_sum: int, optional

        :param aws_host_top99p_sum: Shows the 99th percentile of all AWS hosts over all hours in the current months for all organizations.
        :type aws_host_top99p_sum: int, optional

        :param aws_lambda_func_count: Shows the average of the number of functions that executed 1 or more times each hour in the current months for all organizations.
        :type aws_lambda_func_count: int, optional

        :param aws_lambda_invocations_sum: Shows the sum of all AWS Lambda invocations over all hours in the current months for all organizations.
        :type aws_lambda_invocations_sum: int, optional

        :param azure_app_service_top99p_sum: Shows the 99th percentile of all Azure app services over all hours in the current months for all organizations.
        :type azure_app_service_top99p_sum: int, optional

        :param azure_host_top99p_sum: Shows the 99th percentile of all Azure hosts over all hours in the current months for all organizations.
        :type azure_host_top99p_sum: int, optional

        :param billable_ingested_bytes_agg_sum: Shows the sum of all log bytes ingested over all hours in the current months for all organizations.
        :type billable_ingested_bytes_agg_sum: int, optional

        :param browser_rum_lite_session_count_agg_sum: Shows the sum of all browser lite sessions over all hours in the current months for all organizations.
        :type browser_rum_lite_session_count_agg_sum: int, optional

        :param browser_rum_replay_session_count_agg_sum: Shows the sum of all browser replay sessions over all hours in the current months for all organizations.
        :type browser_rum_replay_session_count_agg_sum: int, optional

        :param browser_rum_units_agg_sum: Shows the sum of all browser RUM units over all hours in the current months for all organizations.
        :type browser_rum_units_agg_sum: int, optional

        :param ci_pipeline_indexed_spans_agg_sum: Shows the sum of all CI pipeline indexed spans over all hours in the current months for all organizations.
        :type ci_pipeline_indexed_spans_agg_sum: int, optional

        :param ci_test_indexed_spans_agg_sum: Shows the sum of all CI test indexed spans over all hours in the current months for all organizations.
        :type ci_test_indexed_spans_agg_sum: int, optional

        :param ci_visibility_pipeline_committers_hwm_sum: Shows the high-water mark of all CI visibility pipeline committers over all hours in the current months for all organizations.
        :type ci_visibility_pipeline_committers_hwm_sum: int, optional

        :param ci_visibility_test_committers_hwm_sum: Shows the high-water mark of all CI visibility test committers over all hours in the current months for all organizations.
        :type ci_visibility_test_committers_hwm_sum: int, optional

        :param container_avg_sum: Shows the average of all distinct containers over all hours in the current months for all organizations.
        :type container_avg_sum: int, optional

        :param container_hwm_sum: Shows the sum of the high-water marks of all distinct containers over all hours in the current months for all organizations.
        :type container_hwm_sum: int, optional

        :param cspm_aas_host_top99p_sum: Shows the 99th percentile of all Cloud Security Posture Management Azure app services hosts over all hours in the current months for all organizations.
        :type cspm_aas_host_top99p_sum: int, optional

        :param cspm_aws_host_top99p_sum: Shows the 99th percentile of all Cloud Security Posture Management AWS hosts over all hours in the current months for all organizations.
        :type cspm_aws_host_top99p_sum: int, optional

        :param cspm_azure_host_top99p_sum: Shows the 99th percentile of all Cloud Security Posture Management Azure hosts over all hours in the current months for all organizations.
        :type cspm_azure_host_top99p_sum: int, optional

        :param cspm_container_avg_sum: Shows the average number of Cloud Security Posture Management containers over all hours in the current months for all organizations.
        :type cspm_container_avg_sum: int, optional

        :param cspm_container_hwm_sum: Shows the sum of the the high-water marks of Cloud Security Posture Management containers over all hours in the current months for all organizations.
        :type cspm_container_hwm_sum: int, optional

        :param cspm_gcp_host_top99p_sum: Shows the 99th percentile of all Cloud Security Posture Management GCP hosts over all hours in the current months for all organizations.
        :type cspm_gcp_host_top99p_sum: int, optional

        :param cspm_host_top99p_sum: Shows the 99th percentile of all Cloud Security Posture Management hosts over all hours in the current months for all organizations.
        :type cspm_host_top99p_sum: int, optional

        :param custom_ts_sum: Shows the average number of distinct custom metrics over all hours in the current months for all organizations.
        :type custom_ts_sum: int, optional

        :param cws_containers_avg_sum: Shows the average of all distinct Cloud Workload Security containers over all hours in the current months for all organizations.
        :type cws_containers_avg_sum: int, optional

        :param cws_host_top99p_sum: Shows the 99th percentile of all Cloud Workload Security hosts over all hours in the current months for all organizations.
        :type cws_host_top99p_sum: int, optional

        :param dbm_host_top99p_sum: Shows the 99th percentile of all Database Monitoring hosts over all hours in the current month for all organizations.
        :type dbm_host_top99p_sum: int, optional

        :param dbm_queries_avg_sum: Shows the average of all distinct Database Monitoring Normalized Queries over all hours in the current month for all organizations.
        :type dbm_queries_avg_sum: int, optional

        :param end_date: Shows the last date of usage in the current months for all organizations.
        :type end_date: datetime, optional

        :param fargate_tasks_count_avg_sum: Shows the average of all Fargate tasks over all hours in the current months for all organizations.
        :type fargate_tasks_count_avg_sum: int, optional

        :param fargate_tasks_count_hwm_sum: Shows the sum of the high-water marks of all Fargate tasks over all hours in the current months for all organizations.
        :type fargate_tasks_count_hwm_sum: int, optional

        :param gcp_host_top99p_sum: Shows the 99th percentile of all GCP hosts over all hours in the current months for all organizations.
        :type gcp_host_top99p_sum: int, optional

        :param heroku_host_top99p_sum: Shows the 99th percentile of all Heroku dynos over all hours in the current months for all organizations.
        :type heroku_host_top99p_sum: int, optional

        :param incident_management_monthly_active_users_hwm_sum: Shows sum of the the high-water marks of incident management monthly active users in the current months for all organizations.
        :type incident_management_monthly_active_users_hwm_sum: int, optional

        :param indexed_events_count_agg_sum: Shows the sum of all log events indexed over all hours in the current months for all organizations.
        :type indexed_events_count_agg_sum: int, optional

        :param infra_host_top99p_sum: Shows the 99th percentile of all distinct infrastructure hosts over all hours in the current months for all organizations.
        :type infra_host_top99p_sum: int, optional

        :param ingested_events_bytes_agg_sum: Shows the sum of all log bytes ingested over all hours in the current months for all organizations.
        :type ingested_events_bytes_agg_sum: int, optional

        :param iot_device_agg_sum: Shows the sum of all IoT devices over all hours in the current months for all organizations.
        :type iot_device_agg_sum: int, optional

        :param iot_device_top99p_sum: Shows the 99th percentile of all IoT devices over all hours in the current months of all organizations.
        :type iot_device_top99p_sum: int, optional

        :param last_updated: Shows the the most recent hour in the current months for all organizations for which all usages were calculated.
        :type last_updated: datetime, optional

        :param live_indexed_events_agg_sum: Shows the sum of all live logs indexed over all hours in the current months for all organizations (data available as of December 1, 2020).
        :type live_indexed_events_agg_sum: int, optional

        :param live_ingested_bytes_agg_sum: Shows the sum of all live logs bytes ingested over all hours in the current months for all organizations (data available as of December 1, 2020).
        :type live_ingested_bytes_agg_sum: int, optional

        :param logs_by_retention: Object containing logs usage data broken down by retention period.
        :type logs_by_retention: LogsByRetention, optional

        :param mobile_rum_lite_session_count_agg_sum: Shows the sum of all mobile lite sessions over all hours in the current months for all organizations.
        :type mobile_rum_lite_session_count_agg_sum: int, optional

        :param mobile_rum_session_count_agg_sum: Shows the sum of all mobile RUM Sessions over all hours in the current months for all organizations.
        :type mobile_rum_session_count_agg_sum: int, optional

        :param mobile_rum_session_count_android_agg_sum: Shows the sum of all mobile RUM Sessions on Android over all hours in the current months for all organizations.
        :type mobile_rum_session_count_android_agg_sum: int, optional

        :param mobile_rum_session_count_ios_agg_sum: Shows the sum of all mobile RUM Sessions on iOS over all hours in the current months for all organizations.
        :type mobile_rum_session_count_ios_agg_sum: int, optional

        :param mobile_rum_session_count_reactnative_agg_sum: Shows the sum of all mobile RUM Sessions on React Native over all hours in the current months for all organizations.
        :type mobile_rum_session_count_reactnative_agg_sum: int, optional

        :param mobile_rum_units_agg_sum: Shows the sum of all mobile RUM units over all hours in the current months for all organizations.
        :type mobile_rum_units_agg_sum: int, optional

        :param netflow_indexed_events_count_agg_sum: Shows the sum of all Network flows indexed over all hours in the current months for all organizations.
        :type netflow_indexed_events_count_agg_sum: int, optional

        :param npm_host_top99p_sum: Shows the 99th percentile of all distinct Networks hosts over all hours in the current months for all organizations.
        :type npm_host_top99p_sum: int, optional

        :param observability_pipelines_bytes_processed_agg_sum: Sum of all observability pipelines bytes processed over all hours in the current months for all organizations.
        :type observability_pipelines_bytes_processed_agg_sum: int, optional

        :param online_archive_events_count_agg_sum: Sum of all online archived events over all hours in the current months for all organizations.
        :type online_archive_events_count_agg_sum: int, optional

        :param opentelemetry_apm_host_top99p_sum: Shows the 99th percentile of APM hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current months for all organizations.
        :type opentelemetry_apm_host_top99p_sum: int, optional

        :param opentelemetry_host_top99p_sum: Shows the 99th percentile of all hosts reported by the Datadog exporter for the OpenTelemetry Collector over all hours in the current months for all organizations.
        :type opentelemetry_host_top99p_sum: int, optional

        :param profiling_container_agent_count_avg: Shows the average number of profiled containers over all hours in the current months for all organizations.
        :type profiling_container_agent_count_avg: int, optional

        :param profiling_host_count_top99p_sum: Shows the 99th percentile of all profiled hosts over all hours in the current months for all organizations.
        :type profiling_host_count_top99p_sum: int, optional

        :param rehydrated_indexed_events_agg_sum: Shows the sum of all rehydrated logs indexed over all hours in the current months for all organizations (data available as of December 1, 2020).
        :type rehydrated_indexed_events_agg_sum: int, optional

        :param rehydrated_ingested_bytes_agg_sum: Shows the sum of all rehydrated logs bytes ingested over all hours in the current months for all organizations (data available as of December 1, 2020).
        :type rehydrated_ingested_bytes_agg_sum: int, optional

        :param rum_browser_and_mobile_session_count: Shows the sum of all mobile sessions and all browser lite and legacy sessions over all hours in the current month for all organizations.
        :type rum_browser_and_mobile_session_count: int, optional

        :param rum_session_count_agg_sum: Shows the sum of all browser RUM Lite Sessions over all hours in the current months for all organizations.
        :type rum_session_count_agg_sum: int, optional

        :param rum_total_session_count_agg_sum: Shows the sum of RUM Sessions (browser and mobile) over all hours in the current months for all organizations.
        :type rum_total_session_count_agg_sum: int, optional

        :param rum_units_agg_sum: Shows the sum of all browser and mobile RUM units over all hours in the current months for all organizations.
        :type rum_units_agg_sum: int, optional

        :param sds_apm_scanned_bytes_sum: Sum of all APM bytes scanned with sensitive data scanner in the current months for all organizations.
        :type sds_apm_scanned_bytes_sum: int, optional

        :param sds_events_scanned_bytes_sum: Sum of all event stream events bytes scanned with sensitive data scanner in the current months for all organizations.
        :type sds_events_scanned_bytes_sum: int, optional

        :param sds_logs_scanned_bytes_sum: Shows the sum of all bytes scanned of logs usage by the Sensitive Data Scanner over all hours in the current month for all organizations.
        :type sds_logs_scanned_bytes_sum: int, optional

        :param sds_rum_scanned_bytes_sum: Sum of all RUM bytes scanned with sensitive data scanner in the current months for all organizations.
        :type sds_rum_scanned_bytes_sum: int, optional

        :param sds_total_scanned_bytes_sum: Shows the sum of all bytes scanned across all usage types by the Sensitive Data Scanner over all hours in the current month for all organizations.
        :type sds_total_scanned_bytes_sum: int, optional

        :param start_date: Shows the first date of usage in the current months for all organizations.
        :type start_date: datetime, optional

        :param synthetics_browser_check_calls_count_agg_sum: Shows the sum of all Synthetic browser tests over all hours in the current months for all organizations.
        :type synthetics_browser_check_calls_count_agg_sum: int, optional

        :param synthetics_check_calls_count_agg_sum: Shows the sum of all Synthetic API tests over all hours in the current months for all organizations.
        :type synthetics_check_calls_count_agg_sum: int, optional

        :param synthetics_parallel_testing_max_slots_hwm_sum: Shows the sum of the high-water marks of used synthetics parallel testing slots over all hours in the current month for all organizations.
        :type synthetics_parallel_testing_max_slots_hwm_sum: int, optional

        :param trace_search_indexed_events_count_agg_sum: Shows the sum of all Indexed Spans indexed over all hours in the current months for all organizations.
        :type trace_search_indexed_events_count_agg_sum: int, optional

        :param twol_ingested_events_bytes_agg_sum: Shows the sum of all ingested APM span bytes over all hours in the current months for all organizations.
        :type twol_ingested_events_bytes_agg_sum: int, optional

        :param usage: An array of objects regarding hourly usage.
        :type usage: [UsageSummaryDate], optional

        :param vsphere_host_top99p_sum: Shows the 99th percentile of all vSphere hosts over all hours in the current months for all organizations.
        :type vsphere_host_top99p_sum: int, optional
        """
        if agent_host_top99p_sum is not unset:
            kwargs["agent_host_top99p_sum"] = agent_host_top99p_sum
        if apm_azure_app_service_host_top99p_sum is not unset:
            kwargs["apm_azure_app_service_host_top99p_sum"] = apm_azure_app_service_host_top99p_sum
        if apm_fargate_count_avg_sum is not unset:
            kwargs["apm_fargate_count_avg_sum"] = apm_fargate_count_avg_sum
        if apm_host_top99p_sum is not unset:
            kwargs["apm_host_top99p_sum"] = apm_host_top99p_sum
        if appsec_fargate_count_avg_sum is not unset:
            kwargs["appsec_fargate_count_avg_sum"] = appsec_fargate_count_avg_sum
        if audit_logs_lines_indexed_agg_sum is not unset:
            kwargs["audit_logs_lines_indexed_agg_sum"] = audit_logs_lines_indexed_agg_sum
        if avg_profiled_fargate_tasks_sum is not unset:
            kwargs["avg_profiled_fargate_tasks_sum"] = avg_profiled_fargate_tasks_sum
        if aws_host_top99p_sum is not unset:
            kwargs["aws_host_top99p_sum"] = aws_host_top99p_sum
        if aws_lambda_func_count is not unset:
            kwargs["aws_lambda_func_count"] = aws_lambda_func_count
        if aws_lambda_invocations_sum is not unset:
            kwargs["aws_lambda_invocations_sum"] = aws_lambda_invocations_sum
        if azure_app_service_top99p_sum is not unset:
            kwargs["azure_app_service_top99p_sum"] = azure_app_service_top99p_sum
        if azure_host_top99p_sum is not unset:
            kwargs["azure_host_top99p_sum"] = azure_host_top99p_sum
        if billable_ingested_bytes_agg_sum is not unset:
            kwargs["billable_ingested_bytes_agg_sum"] = billable_ingested_bytes_agg_sum
        if browser_rum_lite_session_count_agg_sum is not unset:
            kwargs["browser_rum_lite_session_count_agg_sum"] = browser_rum_lite_session_count_agg_sum
        if browser_rum_replay_session_count_agg_sum is not unset:
            kwargs["browser_rum_replay_session_count_agg_sum"] = browser_rum_replay_session_count_agg_sum
        if browser_rum_units_agg_sum is not unset:
            kwargs["browser_rum_units_agg_sum"] = browser_rum_units_agg_sum
        if ci_pipeline_indexed_spans_agg_sum is not unset:
            kwargs["ci_pipeline_indexed_spans_agg_sum"] = ci_pipeline_indexed_spans_agg_sum
        if ci_test_indexed_spans_agg_sum is not unset:
            kwargs["ci_test_indexed_spans_agg_sum"] = ci_test_indexed_spans_agg_sum
        if ci_visibility_pipeline_committers_hwm_sum is not unset:
            kwargs["ci_visibility_pipeline_committers_hwm_sum"] = ci_visibility_pipeline_committers_hwm_sum
        if ci_visibility_test_committers_hwm_sum is not unset:
            kwargs["ci_visibility_test_committers_hwm_sum"] = ci_visibility_test_committers_hwm_sum
        if container_avg_sum is not unset:
            kwargs["container_avg_sum"] = container_avg_sum
        if container_hwm_sum is not unset:
            kwargs["container_hwm_sum"] = container_hwm_sum
        if cspm_aas_host_top99p_sum is not unset:
            kwargs["cspm_aas_host_top99p_sum"] = cspm_aas_host_top99p_sum
        if cspm_aws_host_top99p_sum is not unset:
            kwargs["cspm_aws_host_top99p_sum"] = cspm_aws_host_top99p_sum
        if cspm_azure_host_top99p_sum is not unset:
            kwargs["cspm_azure_host_top99p_sum"] = cspm_azure_host_top99p_sum
        if cspm_container_avg_sum is not unset:
            kwargs["cspm_container_avg_sum"] = cspm_container_avg_sum
        if cspm_container_hwm_sum is not unset:
            kwargs["cspm_container_hwm_sum"] = cspm_container_hwm_sum
        if cspm_gcp_host_top99p_sum is not unset:
            kwargs["cspm_gcp_host_top99p_sum"] = cspm_gcp_host_top99p_sum
        if cspm_host_top99p_sum is not unset:
            kwargs["cspm_host_top99p_sum"] = cspm_host_top99p_sum
        if custom_ts_sum is not unset:
            kwargs["custom_ts_sum"] = custom_ts_sum
        if cws_containers_avg_sum is not unset:
            kwargs["cws_containers_avg_sum"] = cws_containers_avg_sum
        if cws_host_top99p_sum is not unset:
            kwargs["cws_host_top99p_sum"] = cws_host_top99p_sum
        if dbm_host_top99p_sum is not unset:
            kwargs["dbm_host_top99p_sum"] = dbm_host_top99p_sum
        if dbm_queries_avg_sum is not unset:
            kwargs["dbm_queries_avg_sum"] = dbm_queries_avg_sum
        if end_date is not unset:
            kwargs["end_date"] = end_date
        if fargate_tasks_count_avg_sum is not unset:
            kwargs["fargate_tasks_count_avg_sum"] = fargate_tasks_count_avg_sum
        if fargate_tasks_count_hwm_sum is not unset:
            kwargs["fargate_tasks_count_hwm_sum"] = fargate_tasks_count_hwm_sum
        if gcp_host_top99p_sum is not unset:
            kwargs["gcp_host_top99p_sum"] = gcp_host_top99p_sum
        if heroku_host_top99p_sum is not unset:
            kwargs["heroku_host_top99p_sum"] = heroku_host_top99p_sum
        if incident_management_monthly_active_users_hwm_sum is not unset:
            kwargs[
                "incident_management_monthly_active_users_hwm_sum"
            ] = incident_management_monthly_active_users_hwm_sum
        if indexed_events_count_agg_sum is not unset:
            kwargs["indexed_events_count_agg_sum"] = indexed_events_count_agg_sum
        if infra_host_top99p_sum is not unset:
            kwargs["infra_host_top99p_sum"] = infra_host_top99p_sum
        if ingested_events_bytes_agg_sum is not unset:
            kwargs["ingested_events_bytes_agg_sum"] = ingested_events_bytes_agg_sum
        if iot_device_agg_sum is not unset:
            kwargs["iot_device_agg_sum"] = iot_device_agg_sum
        if iot_device_top99p_sum is not unset:
            kwargs["iot_device_top99p_sum"] = iot_device_top99p_sum
        if last_updated is not unset:
            kwargs["last_updated"] = last_updated
        if live_indexed_events_agg_sum is not unset:
            kwargs["live_indexed_events_agg_sum"] = live_indexed_events_agg_sum
        if live_ingested_bytes_agg_sum is not unset:
            kwargs["live_ingested_bytes_agg_sum"] = live_ingested_bytes_agg_sum
        if logs_by_retention is not unset:
            kwargs["logs_by_retention"] = logs_by_retention
        if mobile_rum_lite_session_count_agg_sum is not unset:
            kwargs["mobile_rum_lite_session_count_agg_sum"] = mobile_rum_lite_session_count_agg_sum
        if mobile_rum_session_count_agg_sum is not unset:
            kwargs["mobile_rum_session_count_agg_sum"] = mobile_rum_session_count_agg_sum
        if mobile_rum_session_count_android_agg_sum is not unset:
            kwargs["mobile_rum_session_count_android_agg_sum"] = mobile_rum_session_count_android_agg_sum
        if mobile_rum_session_count_ios_agg_sum is not unset:
            kwargs["mobile_rum_session_count_ios_agg_sum"] = mobile_rum_session_count_ios_agg_sum
        if mobile_rum_session_count_reactnative_agg_sum is not unset:
            kwargs["mobile_rum_session_count_reactnative_agg_sum"] = mobile_rum_session_count_reactnative_agg_sum
        if mobile_rum_units_agg_sum is not unset:
            kwargs["mobile_rum_units_agg_sum"] = mobile_rum_units_agg_sum
        if netflow_indexed_events_count_agg_sum is not unset:
            kwargs["netflow_indexed_events_count_agg_sum"] = netflow_indexed_events_count_agg_sum
        if npm_host_top99p_sum is not unset:
            kwargs["npm_host_top99p_sum"] = npm_host_top99p_sum
        if observability_pipelines_bytes_processed_agg_sum is not unset:
            kwargs["observability_pipelines_bytes_processed_agg_sum"] = observability_pipelines_bytes_processed_agg_sum
        if online_archive_events_count_agg_sum is not unset:
            kwargs["online_archive_events_count_agg_sum"] = online_archive_events_count_agg_sum
        if opentelemetry_apm_host_top99p_sum is not unset:
            kwargs["opentelemetry_apm_host_top99p_sum"] = opentelemetry_apm_host_top99p_sum
        if opentelemetry_host_top99p_sum is not unset:
            kwargs["opentelemetry_host_top99p_sum"] = opentelemetry_host_top99p_sum
        if profiling_container_agent_count_avg is not unset:
            kwargs["profiling_container_agent_count_avg"] = profiling_container_agent_count_avg
        if profiling_host_count_top99p_sum is not unset:
            kwargs["profiling_host_count_top99p_sum"] = profiling_host_count_top99p_sum
        if rehydrated_indexed_events_agg_sum is not unset:
            kwargs["rehydrated_indexed_events_agg_sum"] = rehydrated_indexed_events_agg_sum
        if rehydrated_ingested_bytes_agg_sum is not unset:
            kwargs["rehydrated_ingested_bytes_agg_sum"] = rehydrated_ingested_bytes_agg_sum
        if rum_browser_and_mobile_session_count is not unset:
            kwargs["rum_browser_and_mobile_session_count"] = rum_browser_and_mobile_session_count
        if rum_session_count_agg_sum is not unset:
            kwargs["rum_session_count_agg_sum"] = rum_session_count_agg_sum
        if rum_total_session_count_agg_sum is not unset:
            kwargs["rum_total_session_count_agg_sum"] = rum_total_session_count_agg_sum
        if rum_units_agg_sum is not unset:
            kwargs["rum_units_agg_sum"] = rum_units_agg_sum
        if sds_apm_scanned_bytes_sum is not unset:
            kwargs["sds_apm_scanned_bytes_sum"] = sds_apm_scanned_bytes_sum
        if sds_events_scanned_bytes_sum is not unset:
            kwargs["sds_events_scanned_bytes_sum"] = sds_events_scanned_bytes_sum
        if sds_logs_scanned_bytes_sum is not unset:
            kwargs["sds_logs_scanned_bytes_sum"] = sds_logs_scanned_bytes_sum
        if sds_rum_scanned_bytes_sum is not unset:
            kwargs["sds_rum_scanned_bytes_sum"] = sds_rum_scanned_bytes_sum
        if sds_total_scanned_bytes_sum is not unset:
            kwargs["sds_total_scanned_bytes_sum"] = sds_total_scanned_bytes_sum
        if start_date is not unset:
            kwargs["start_date"] = start_date
        if synthetics_browser_check_calls_count_agg_sum is not unset:
            kwargs["synthetics_browser_check_calls_count_agg_sum"] = synthetics_browser_check_calls_count_agg_sum
        if synthetics_check_calls_count_agg_sum is not unset:
            kwargs["synthetics_check_calls_count_agg_sum"] = synthetics_check_calls_count_agg_sum
        if synthetics_parallel_testing_max_slots_hwm_sum is not unset:
            kwargs["synthetics_parallel_testing_max_slots_hwm_sum"] = synthetics_parallel_testing_max_slots_hwm_sum
        if trace_search_indexed_events_count_agg_sum is not unset:
            kwargs["trace_search_indexed_events_count_agg_sum"] = trace_search_indexed_events_count_agg_sum
        if twol_ingested_events_bytes_agg_sum is not unset:
            kwargs["twol_ingested_events_bytes_agg_sum"] = twol_ingested_events_bytes_agg_sum
        if usage is not unset:
            kwargs["usage"] = usage
        if vsphere_host_top99p_sum is not unset:
            kwargs["vsphere_host_top99p_sum"] = vsphere_host_top99p_sum
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    UnsetType,
    unset,
)
from datadog_api_client.v1.model.tag_to_hosts import TagToHosts
from datadog_api_client.v1.model.host_tags import HostTags


class TagsApi:
    """
    The tag endpoint allows you to assign tags to hosts,
    for example: ``role:database``. Those tags are applied to
    all metrics sent by the host. Refer to hosts by name
    ( ``yourhost.example.com`` ) when fetching and applying
    tags to a particular host.

    The component of your infrastructure responsible for a tag is identified
    by a source. For example, some valid sources include nagios, hudson, jenkins,
    users, feed, chef, puppet, git, bitbucket, fabric, capistrano, etc.

    Read more about tags on the dedicated
    `documentation page <https://docs.datadoghq.com/tagging>`_.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._create_host_tags_endpoint = _Endpoint(
            settings={
                "response_type": (HostTags,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                "operation_id": "create_host_tags",
                "http_method": "POST",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "host_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "host_name",
                    "location": "path",
                },
                "source": {
                    "openapi_types": (str,),
                    "attribute": "source",
                    "location": "query",
                },
                "body": {
                    "required": True,
                    "openapi_types": (HostTags,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._delete_host_tags_endpoint = _Endpoint(
            settings={
                "response_type": None,
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                "operation_id": "delete_host_tags",
                "http_method": "DELETE",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "host_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "host_name",
                    "location": "path",
                },
                "source": {
                    "openapi_types": (str,),
                    "attribute": "source",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["*/*"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._get_host_tags_endpoint = _Endpoint(
            settings={
                "response_type": (HostTags,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                "operation_id": "get_host_tags",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "host_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "host_name",
                    "location": "path",
                },
                "source": {
                    "openapi_types": (str,),
                    "attribute": "source",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._list_host_tags_endpoint = _Endpoint(
            settings={
                "response_type": (TagToHosts,),
                "auth": ["apiKeyAuth", "appKeyAuth", "AuthZ"],
                "endpoint_path": "/api/v1/tags/hosts",
                "operation_id": "list_host_tags",
                "http_method": "GET",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "source": {
                    "openapi_types": (str,),
                    "attribute": "source",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._update_host_tags_endpoint = _Endpoint(
            settings={
                "response_type": (HostTags,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v1/tags/hosts/{host_name}",
                "operation_id": "update_host_tags",
                "http_method": "PUT",
                "version": "v1",
                "servers": None,
            },
            params_map={
                "host_name": {
                    "required": True,
                    "openapi_types": (str,),
                    "attribute": "host_name",
                    "location": "path",
                },
                "source": {
                    "openapi_types": (str,),
                    "attribute": "source",
                    "location": "query",
                },
                "body": {
                    "required": True,
                    "openapi_types": (HostTags,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

    def create_host_tags(
        self,
        host_name: str,
        body: HostTags,
        *,
        source: Union[str, UnsetType] = unset,
    ) -> HostTags:
        """Add tags to a host.

        This endpoint allows you to add new tags to a host,
        optionally specifying where these tags come from.

        :param host_name: This endpoint allows you to add new tags to a host, optionally specifying where the tags came from.
        :type host_name: str
        :param body: Update host tags request body.
        :type body: HostTags
        :param source: The source of the tags.
            `Complete list of source attribute values <https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value>`_.
        :type source: str, optional
        :rtype: HostTags
        """
        kwargs: Dict[str, Any] = {}
        kwargs["host_name"] = host_name

        if source is not unset:
            kwargs["source"] = source

        kwargs["body"] = body

        return self._create_host_tags_endpoint.call_with_http_info(**kwargs)

    def delete_host_tags(
        self,
        host_name: str,
        *,
        source: Union[str, UnsetType] = unset,
    ) -> None:
        """Remove host tags.

        This endpoint allows you to remove all user-assigned tags
        for a single host.

        :param host_name: This endpoint allows you to remove all user-assigned tags for a single host.
        :type host_name: str
        :param source: The source of the tags (for example chef, puppet).
            `Complete list of source attribute values <https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value>`_.
        :type source: str, optional
        :rtype: None
        """
        kwargs: Dict[str, Any] = {}
        kwargs["host_name"] = host_name

        if source is not unset:
            kwargs["source"] = source

        return self._delete_host_tags_endpoint.call_with_http_info(**kwargs)

    def get_host_tags(
        self,
        host_name: str,
        *,
        source: Union[str, UnsetType] = unset,
    ) -> HostTags:
        """Get host tags.

        Return the list of tags that apply to a given host.

        :param host_name: When specified, filters list of tags to those tags with the specified source.
        :type host_name: str
        :param source: Source to filter.
        :type source: str, optional
        :rtype: HostTags
        """
        kwargs: Dict[str, Any] = {}
        kwargs["host_name"] = host_name

        if source is not unset:
            kwargs["source"] = source

        return self._get_host_tags_endpoint.call_with_http_info(**kwargs)

    def list_host_tags(
        self,
        *,
        source: Union[str, UnsetType] = unset,
    ) -> TagToHosts:
        """Get Tags.

        Return a mapping of tags to hosts for your whole infrastructure.

        :param source: When specified, filters host list to those tags with the specified source.
        :type source: str, optional
        :rtype: TagToHosts
        """
        kwargs: Dict[str, Any] = {}
        if source is not unset:
            kwargs["source"] = source

        return self._list_host_tags_endpoint.call_with_http_info(**kwargs)

    def update_host_tags(
        self,
        host_name: str,
        body: HostTags,
        *,
        source: Union[str, UnsetType] = unset,
    ) -> HostTags:
        """Update host tags.

        This endpoint allows you to update/replace all tags in
        an integration source with those supplied in the request.

        :param host_name: This endpoint allows you to update/replace all in an integration source with those supplied in the request.
        :type host_name: str
        :param body: Add tags to host
        :type body: HostTags
        :param source: The source of the tags (for example chef, puppet).
            `Complete list of source attribute values <https://docs.datadoghq.com/integrations/faq/list-of-api-source-attribute-value>`_
        :type source: str, optional
        :rtype: HostTags
        """
        kwargs: Dict[str, Any] = {}
        kwargs["host_name"] = host_name

        if source is not unset:
            kwargs["source"] = source

        kwargs["body"] = body

        return self._update_host_tags_endpoint.call_with_http_info(**kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.scatterplot_widget_aggregator import ScatterplotWidgetAggregator
    from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
    from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition


class ScatterPlotRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.scatterplot_widget_aggregator import ScatterplotWidgetAggregator
        from datadog_api_client.v1.model.log_query_definition import LogQueryDefinition
        from datadog_api_client.v1.model.process_query_definition import ProcessQueryDefinition

        return {
            "aggregator": (ScatterplotWidgetAggregator,),
            "apm_query": (LogQueryDefinition,),
            "event_query": (LogQueryDefinition,),
            "log_query": (LogQueryDefinition,),
            "network_query": (LogQueryDefinition,),
            "process_query": (ProcessQueryDefinition,),
            "profile_metrics_query": (LogQueryDefinition,),
            "q": (str,),
            "rum_query": (LogQueryDefinition,),
            "security_query": (LogQueryDefinition,),
        }

    attribute_map = {
        "aggregator": "aggregator",
        "apm_query": "apm_query",
        "event_query": "event_query",
        "log_query": "log_query",
        "network_query": "network_query",
        "process_query": "process_query",
        "profile_metrics_query": "profile_metrics_query",
        "q": "q",
        "rum_query": "rum_query",
        "security_query": "security_query",
    }

    def __init__(
        self_,
        aggregator: Union[ScatterplotWidgetAggregator, UnsetType] = unset,
        apm_query: Union[LogQueryDefinition, UnsetType] = unset,
        event_query: Union[LogQueryDefinition, UnsetType] = unset,
        log_query: Union[LogQueryDefinition, UnsetType] = unset,
        network_query: Union[LogQueryDefinition, UnsetType] = unset,
        process_query: Union[ProcessQueryDefinition, UnsetType] = unset,
        profile_metrics_query: Union[LogQueryDefinition, UnsetType] = unset,
        q: Union[str, UnsetType] = unset,
        rum_query: Union[LogQueryDefinition, UnsetType] = unset,
        security_query: Union[LogQueryDefinition, UnsetType] = unset,
        **kwargs,
    ):
        """
        Updated scatter plot.

        :param aggregator: Aggregator used for the request.
        :type aggregator: ScatterplotWidgetAggregator, optional

        :param apm_query: The log query.
        :type apm_query: LogQueryDefinition, optional

        :param event_query: The log query.
        :type event_query: LogQueryDefinition, optional

        :param log_query: The log query.
        :type log_query: LogQueryDefinition, optional

        :param network_query: The log query.
        :type network_query: LogQueryDefinition, optional

        :param process_query: The process query to use in the widget.
        :type process_query: ProcessQueryDefinition, optional

        :param profile_metrics_query: The log query.
        :type profile_metrics_query: LogQueryDefinition, optional

        :param q: Query definition.
        :type q: str, optional

        :param rum_query: The log query.
        :type rum_query: LogQueryDefinition, optional

        :param security_query: The log query.
        :type security_query: LogQueryDefinition, optional
        """
        if aggregator is not unset:
            kwargs["aggregator"] = aggregator
        if apm_query is not unset:
            kwargs["apm_query"] = apm_query
        if event_query is not unset:
            kwargs["event_query"] = event_query
        if log_query is not unset:
            kwargs["log_query"] = log_query
        if network_query is not unset:
            kwargs["network_query"] = network_query
        if process_query is not unset:
            kwargs["process_query"] = process_query
        if profile_metrics_query is not unset:
            kwargs["profile_metrics_query"] = profile_metrics_query
        if q is not unset:
            kwargs["q"] = q
        if rum_query is not unset:
            kwargs["rum_query"] = rum_query
        if security_query is not unset:
            kwargs["security_query"] = security_query
        super().__init__(kwargs)



"""
Create a new dashboard with scatterplot widget
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.dashboards_api import DashboardsApi
from datadog_api_client.v1.model.dashboard import Dashboard
from datadog_api_client.v1.model.dashboard_layout_type import DashboardLayoutType
from datadog_api_client.v1.model.formula_and_function_metric_aggregation import FormulaAndFunctionMetricAggregation
from datadog_api_client.v1.model.formula_and_function_metric_data_source import FormulaAndFunctionMetricDataSource
from datadog_api_client.v1.model.formula_and_function_metric_query_definition import (
    FormulaAndFunctionMetricQueryDefinition,
)
from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
from datadog_api_client.v1.model.scatter_plot_widget_definition import ScatterPlotWidgetDefinition
from datadog_api_client.v1.model.scatter_plot_widget_definition_requests import ScatterPlotWidgetDefinitionRequests
from datadog_api_client.v1.model.scatter_plot_widget_definition_type import ScatterPlotWidgetDefinitionType
from datadog_api_client.v1.model.scatterplot_dimension import ScatterplotDimension
from datadog_api_client.v1.model.scatterplot_table_request import ScatterplotTableRequest
from datadog_api_client.v1.model.scatterplot_widget_formula import ScatterplotWidgetFormula
from datadog_api_client.v1.model.widget import Widget
from datadog_api_client.v1.model.widget_axis import WidgetAxis
from datadog_api_client.v1.model.widget_layout import WidgetLayout
from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
from datadog_api_client.v1.model.widget_time import WidgetTime

body = Dashboard(
    title="Example-Create_a_new_dashboard_with_scatterplot_widget",
    description="",
    widgets=[
        Widget(
            layout=WidgetLayout(
                x=0,
                y=0,
                width=47,
                height=15,
            ),
            definition=ScatterPlotWidgetDefinition(
                title="",
                title_size="16",
                title_align=WidgetTextAlign.LEFT,
                time=WidgetTime(),
                type=ScatterPlotWidgetDefinitionType.SCATTERPLOT,
                requests=ScatterPlotWidgetDefinitionRequests(
                    table=ScatterplotTableRequest(
                        formulas=[
                            ScatterplotWidgetFormula(
                                formula="query1",
                                dimension=ScatterplotDimension.X,
                                alias="",
                            ),
                            ScatterplotWidgetFormula(
                                formula="query2",
                                dimension=ScatterplotDimension.Y,
                                alias="",
                            ),
                        ],
                        queries=[
                            FormulaAndFunctionMetricQueryDefinition(
                                data_source=FormulaAndFunctionMetricDataSource.METRICS,
                                name="query1",
                                query="avg:system.cpu.user{*} by {service}",
                                aggregator=FormulaAndFunctionMetricAggregation.AVG,
                            ),
                            FormulaAndFunctionMetricQueryDefinition(
                                data_source=FormulaAndFunctionMetricDataSource.METRICS,
                                name="query2",
                                query="avg:system.mem.used{*} by {service}",
                                aggregator=FormulaAndFunctionMetricAggregation.AVG,
                            ),
                        ],
                        response_format=FormulaAndFunctionResponseFormat.SCALAR,
                    ),
                ),
                xaxis=WidgetAxis(
                    scale="linear",
                    include_zero=True,
                    min="auto",
                    max="auto",
                ),
                yaxis=WidgetAxis(
                    scale="linear",
                    include_zero=True,
                    min="auto",
                    max="auto",
                ),
                color_by_groups=[],
            ),
        ),
    ],
    template_variables=[],
    layout_type=DashboardLayoutType.FREE,
    is_read_only=False,
    notify_list=[],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardsApi(api_client)
    response = api_instance.create_dashboard(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class DashboardReflowType(ModelSimple):
    """
    Reflow type for a **new dashboard layout** dashboard. Set this only when layout type is 'ordered'.
        If set to 'fixed', the dashboard expects all widgets to have a layout, and if it's set to 'auto',
        widgets should not have layouts.

    :param value: Must be one of ["auto", "fixed"].
    :type value: str
    """

    allowed_values = {
        "auto",
        "fixed",
    }
    AUTO: ClassVar["DashboardReflowType"]
    FIXED: ClassVar["DashboardReflowType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


DashboardReflowType.AUTO = DashboardReflowType("auto")
DashboardReflowType.FIXED = DashboardReflowType("fixed")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.notebook_update_data_attributes import NotebookUpdateDataAttributes
    from datadog_api_client.v1.model.notebook_resource_type import NotebookResourceType


class NotebookUpdateData(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.notebook_update_data_attributes import NotebookUpdateDataAttributes
        from datadog_api_client.v1.model.notebook_resource_type import NotebookResourceType

        return {
            "attributes": (NotebookUpdateDataAttributes,),
            "type": (NotebookResourceType,),
        }

    attribute_map = {
        "attributes": "attributes",
        "type": "type",
    }

    def __init__(self_, attributes: NotebookUpdateDataAttributes, type: NotebookResourceType, **kwargs):
        """
        The data for a notebook update request.

        :param attributes: The data attributes of a notebook.
        :type attributes: NotebookUpdateDataAttributes

        :param type: Type of the Notebook resource.
        :type type: NotebookResourceType
        """
        super().__init__(kwargs)

        self_.attributes = attributes
        self_.type = type



"""
Update a RUM application returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.rum_api import RUMApi
from datadog_api_client.v2.model.rum_application_update import RUMApplicationUpdate
from datadog_api_client.v2.model.rum_application_update_attributes import RUMApplicationUpdateAttributes
from datadog_api_client.v2.model.rum_application_update_request import RUMApplicationUpdateRequest
from datadog_api_client.v2.model.rum_application_update_type import RUMApplicationUpdateType

# there is a valid "rum_application" in the system
RUM_APPLICATION_DATA_ID = environ["RUM_APPLICATION_DATA_ID"]

body = RUMApplicationUpdateRequest(
    data=RUMApplicationUpdate(
        attributes=RUMApplicationUpdateAttributes(
            name="updated_name_for_my_existing_rum_application",
            type="browser",
        ),
        id=RUM_APPLICATION_DATA_ID,
        type=RUMApplicationUpdateType.RUM_APPLICATION_UPDATE,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = RUMApi(api_client)
    response = api_instance.update_rum_application(id=RUM_APPLICATION_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class UsageAttributionAggregatesBody(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "agg_type": (str,),
            "field": (str,),
            "value": (float,),
        }

    attribute_map = {
        "agg_type": "agg_type",
        "field": "field",
        "value": "value",
    }

    def __init__(
        self_,
        agg_type: Union[str, UnsetType] = unset,
        field: Union[str, UnsetType] = unset,
        value: Union[float, UnsetType] = unset,
        **kwargs,
    ):
        """
        The object containing the aggregates.

        :param agg_type: The aggregate type.
        :type agg_type: str, optional

        :param field: The field.
        :type field: str, optional

        :param value: The value for a given field.
        :type value: float, optional
        """
        if agg_type is not unset:
            kwargs["agg_type"] = agg_type
        if field is not unset:
            kwargs["field"] = field
        if value is not unset:
            kwargs["value"] = value
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_formula import WidgetFormula
    from datadog_api_client.v1.model.formula_and_function_query_definition import FormulaAndFunctionQueryDefinition
    from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat
    from datadog_api_client.v1.model.formula_and_function_metric_query_definition import (
        FormulaAndFunctionMetricQueryDefinition,
    )
    from datadog_api_client.v1.model.formula_and_function_event_query_definition import (
        FormulaAndFunctionEventQueryDefinition,
    )
    from datadog_api_client.v1.model.formula_and_function_process_query_definition import (
        FormulaAndFunctionProcessQueryDefinition,
    )
    from datadog_api_client.v1.model.formula_and_function_apm_dependency_stats_query_definition import (
        FormulaAndFunctionApmDependencyStatsQueryDefinition,
    )
    from datadog_api_client.v1.model.formula_and_function_apm_resource_stats_query_definition import (
        FormulaAndFunctionApmResourceStatsQueryDefinition,
    )


class TreeMapWidgetRequest(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_formula import WidgetFormula
        from datadog_api_client.v1.model.formula_and_function_query_definition import FormulaAndFunctionQueryDefinition
        from datadog_api_client.v1.model.formula_and_function_response_format import FormulaAndFunctionResponseFormat

        return {
            "formulas": ([WidgetFormula],),
            "q": (str,),
            "queries": ([FormulaAndFunctionQueryDefinition],),
            "response_format": (FormulaAndFunctionResponseFormat,),
        }

    attribute_map = {
        "formulas": "formulas",
        "q": "q",
        "queries": "queries",
        "response_format": "response_format",
    }

    def __init__(
        self_,
        formulas: Union[List[WidgetFormula], UnsetType] = unset,
        q: Union[str, UnsetType] = unset,
        queries: Union[
            List[
                Union[
                    FormulaAndFunctionQueryDefinition,
                    FormulaAndFunctionMetricQueryDefinition,
                    FormulaAndFunctionEventQueryDefinition,
                    FormulaAndFunctionProcessQueryDefinition,
                    FormulaAndFunctionApmDependencyStatsQueryDefinition,
                    FormulaAndFunctionApmResourceStatsQueryDefinition,
                ]
            ],
            UnsetType,
        ] = unset,
        response_format: Union[FormulaAndFunctionResponseFormat, UnsetType] = unset,
        **kwargs,
    ):
        """
        An updated treemap widget.

        :param formulas: List of formulas that operate on queries.
        :type formulas: [WidgetFormula], optional

        :param q: The widget metrics query.
        :type q: str, optional

        :param queries: List of queries that can be returned directly or used in formulas.
        :type queries: [FormulaAndFunctionQueryDefinition], optional

        :param response_format: Timeseries or Scalar response.
        :type response_format: FormulaAndFunctionResponseFormat, optional
        """
        if formulas is not unset:
            kwargs["formulas"] = formulas
        if q is not unset:
            kwargs["q"] = q
        if queries is not unset:
            kwargs["queries"] = queries
        if response_format is not unset:
            kwargs["response_format"] = response_format
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class ApmStatsQueryRowType(ModelSimple):
    """
    The level of detail for the request.

    :param value: Must be one of ["service", "resource", "span"].
    :type value: str
    """

    allowed_values = {
        "service",
        "resource",
        "span",
    }
    SERVICE: ClassVar["ApmStatsQueryRowType"]
    RESOURCE: ClassVar["ApmStatsQueryRowType"]
    SPAN: ClassVar["ApmStatsQueryRowType"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


ApmStatsQueryRowType.SERVICE = ApmStatsQueryRowType("service")
ApmStatsQueryRowType.RESOURCE = ApmStatsQueryRowType("resource")
ApmStatsQueryRowType.SPAN = ApmStatsQueryRowType("span")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.formula_and_function_metric_aggregation import FormulaAndFunctionMetricAggregation
    from datadog_api_client.v1.model.formula_and_function_process_query_data_source import (
        FormulaAndFunctionProcessQueryDataSource,
    )
    from datadog_api_client.v1.model.query_sort_order import QuerySortOrder


class FormulaAndFunctionProcessQueryDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.formula_and_function_metric_aggregation import (
            FormulaAndFunctionMetricAggregation,
        )
        from datadog_api_client.v1.model.formula_and_function_process_query_data_source import (
            FormulaAndFunctionProcessQueryDataSource,
        )
        from datadog_api_client.v1.model.query_sort_order import QuerySortOrder

        return {
            "aggregator": (FormulaAndFunctionMetricAggregation,),
            "data_source": (FormulaAndFunctionProcessQueryDataSource,),
            "is_normalized_cpu": (bool,),
            "limit": (int,),
            "metric": (str,),
            "name": (str,),
            "sort": (QuerySortOrder,),
            "tag_filters": ([str],),
            "text_filter": (str,),
        }

    attribute_map = {
        "aggregator": "aggregator",
        "data_source": "data_source",
        "is_normalized_cpu": "is_normalized_cpu",
        "limit": "limit",
        "metric": "metric",
        "name": "name",
        "sort": "sort",
        "tag_filters": "tag_filters",
        "text_filter": "text_filter",
    }

    def __init__(
        self_,
        data_source: FormulaAndFunctionProcessQueryDataSource,
        metric: str,
        name: str,
        aggregator: Union[FormulaAndFunctionMetricAggregation, UnsetType] = unset,
        is_normalized_cpu: Union[bool, UnsetType] = unset,
        limit: Union[int, UnsetType] = unset,
        sort: Union[QuerySortOrder, UnsetType] = unset,
        tag_filters: Union[List[str], UnsetType] = unset,
        text_filter: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Process query using formulas and functions.

        :param aggregator: The aggregation methods available for metrics queries.
        :type aggregator: FormulaAndFunctionMetricAggregation, optional

        :param data_source: Data sources that rely on the process backend.
        :type data_source: FormulaAndFunctionProcessQueryDataSource

        :param is_normalized_cpu: Whether to normalize the CPU percentages.
        :type is_normalized_cpu: bool, optional

        :param limit: Number of hits to return.
        :type limit: int, optional

        :param metric: Process metric name.
        :type metric: str

        :param name: Name of query for use in formulas.
        :type name: str

        :param sort: Direction of sort.
        :type sort: QuerySortOrder, optional

        :param tag_filters: An array of tags to filter by.
        :type tag_filters: [str], optional

        :param text_filter: Text to use as filter.
        :type text_filter: str, optional
        """
        if aggregator is not unset:
            kwargs["aggregator"] = aggregator
        if is_normalized_cpu is not unset:
            kwargs["is_normalized_cpu"] = is_normalized_cpu
        if limit is not unset:
            kwargs["limit"] = limit
        if sort is not unset:
            kwargs["sort"] = sort
        if tag_filters is not unset:
            kwargs["tag_filters"] = tag_filters
        if text_filter is not unset:
            kwargs["text_filter"] = text_filter
        super().__init__(kwargs)

        self_.data_source = data_source
        self_.metric = metric
        self_.name = name



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_category_processor_category import LogsCategoryProcessorCategory
    from datadog_api_client.v1.model.logs_category_processor_type import LogsCategoryProcessorType


class LogsCategoryProcessor(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_category_processor_category import LogsCategoryProcessorCategory
        from datadog_api_client.v1.model.logs_category_processor_type import LogsCategoryProcessorType

        return {
            "categories": ([LogsCategoryProcessorCategory],),
            "is_enabled": (bool,),
            "name": (str,),
            "target": (str,),
            "type": (LogsCategoryProcessorType,),
        }

    attribute_map = {
        "categories": "categories",
        "is_enabled": "is_enabled",
        "name": "name",
        "target": "target",
        "type": "type",
    }

    def __init__(
        self_,
        categories: List[LogsCategoryProcessorCategory],
        target: str,
        type: LogsCategoryProcessorType,
        is_enabled: Union[bool, UnsetType] = unset,
        name: Union[str, UnsetType] = unset,
        **kwargs,
    ):
        """
        Use the Category Processor to add a new attribute (without spaces or special characters in the new attribute name)
        to a log matching a provided search query. Use categories to create groups for an analytical view.
        For example, URL groups, machine groups, environments, and response time buckets.

        **Notes** :

        * The syntax of the query is the one of Logs Explorer search bar.
          The query can be done on any log attribute or tag, whether it is a facet or not.
          Wildcards can also be used inside your query.
        * Once the log has matched one of the Processor queries, it stops.
          Make sure they are properly ordered in case a log could match several queries.
        * The names of the categories must be unique.
        * Once defined in the Category Processor, you can map categories to log status using the Log Status Remapper.

        :param categories: Array of filters to match or not a log and their
            corresponding ``name`` to assign a custom value to the log.
        :type categories: [LogsCategoryProcessorCategory]

        :param is_enabled: Whether or not the processor is enabled.
        :type is_enabled: bool, optional

        :param name: Name of the processor.
        :type name: str, optional

        :param target: Name of the target attribute which value is defined by the matching category.
        :type target: str

        :param type: Type of logs category processor.
        :type type: LogsCategoryProcessorType
        """
        if is_enabled is not unset:
            kwargs["is_enabled"] = is_enabled
        if name is not unset:
            kwargs["name"] = name
        super().__init__(kwargs)

        self_.categories = categories
        self_.target = target
        self_.type = type



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.logs_api_error import LogsAPIError


class LogsAPIErrorResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.logs_api_error import LogsAPIError

        return {
            "error": (LogsAPIError,),
        }

    attribute_map = {
        "error": "error",
    }

    def __init__(self_, error: Union[LogsAPIError, UnsetType] = unset, **kwargs):
        """
        Response returned by the Logs API when errors occur.

        :param error: Error returned by the Logs API
        :type error: LogsAPIError, optional
        """
        if error is not unset:
            kwargs["error"] = error
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


class IncidentResponseMetaPagination(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "next_offset": (int,),
            "offset": (int,),
            "size": (int,),
        }

    attribute_map = {
        "next_offset": "next_offset",
        "offset": "offset",
        "size": "size",
    }

    def __init__(
        self_,
        next_offset: Union[int, UnsetType] = unset,
        offset: Union[int, UnsetType] = unset,
        size: Union[int, UnsetType] = unset,
        **kwargs,
    ):
        """
        Pagination properties.

        :param next_offset: The index of the first element in the next page of results. Equal to page size added to the current offset.
        :type next_offset: int, optional

        :param offset: The index of the first element in the results.
        :type offset: int, optional

        :param size: Maximum size of pages to return.
        :type size: int, optional
        """
        if next_offset is not unset:
            kwargs["next_offset"] = next_offset
        if offset is not unset:
            kwargs["offset"] = offset
        if size is not unset:
            kwargs["size"] = size
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SearchSLOTimeframe(ModelSimple):
    """
    The SLO time window options.

    :param value: Must be one of ["7d", "30d", "90d"].
    :type value: str
    """

    allowed_values = {
        "7d",
        "30d",
        "90d",
    }
    SEVEN_DAYS: ClassVar["SearchSLOTimeframe"]
    THIRTY_DAYS: ClassVar["SearchSLOTimeframe"]
    NINETY_DAYS: ClassVar["SearchSLOTimeframe"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SearchSLOTimeframe.SEVEN_DAYS = SearchSLOTimeframe("7d")
SearchSLOTimeframe.THIRTY_DAYS = SearchSLOTimeframe("30d")
SearchSLOTimeframe.NINETY_DAYS = SearchSLOTimeframe("90d")



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

import collections
from typing import Any, Dict, Union

from datadog_api_client.api_client import ApiClient, Endpoint as _Endpoint
from datadog_api_client.model_utils import (
    datetime,
    set_attribute_from_path,
    get_attribute_from_path,
    UnsetType,
    unset,
)
from datadog_api_client.v2.model.content_encoding import ContentEncoding
from datadog_api_client.v2.model.http_log import HTTPLog
from datadog_api_client.v2.model.logs_aggregate_response import LogsAggregateResponse
from datadog_api_client.v2.model.logs_aggregate_request import LogsAggregateRequest
from datadog_api_client.v2.model.logs_list_response import LogsListResponse
from datadog_api_client.v2.model.logs_storage_tier import LogsStorageTier
from datadog_api_client.v2.model.logs_sort import LogsSort
from datadog_api_client.v2.model.log import Log
from datadog_api_client.v2.model.logs_list_request import LogsListRequest


class LogsApi:
    """
    Search your logs and send them to your Datadog platform over HTTP.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

        self._aggregate_logs_endpoint = _Endpoint(
            settings={
                "response_type": (LogsAggregateResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/analytics/aggregate",
                "operation_id": "aggregate_logs",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "required": True,
                    "openapi_types": (LogsAggregateRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_logs_endpoint = _Endpoint(
            settings={
                "response_type": (LogsListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/events/search",
                "operation_id": "list_logs",
                "http_method": "POST",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "body": {
                    "openapi_types": (LogsListRequest,),
                    "location": "body",
                },
            },
            headers_map={"accept": ["application/json"], "content_type": ["application/json"]},
            api_client=api_client,
        )

        self._list_logs_get_endpoint = _Endpoint(
            settings={
                "response_type": (LogsListResponse,),
                "auth": ["apiKeyAuth", "appKeyAuth"],
                "endpoint_path": "/api/v2/logs/events",
                "operation_id": "list_logs_get",
                "http_method": "GET",
                "version": "v2",
                "servers": None,
            },
            params_map={
                "filter_query": {
                    "openapi_types": (str,),
                    "attribute": "filter[query]",
                    "location": "query",
                },
                "filter_index": {
                    "openapi_types": (str,),
                    "attribute": "filter[index]",
                    "location": "query",
                },
                "filter_from": {
                    "openapi_types": (datetime,),
                    "attribute": "filter[from]",
                    "location": "query",
                },
                "filter_to": {
                    "openapi_types": (datetime,),
                    "attribute": "filter[to]",
                    "location": "query",
                },
                "filter_storage_tier": {
                    "openapi_types": (LogsStorageTier,),
                    "attribute": "filter[storage_tier]",
                    "location": "query",
                },
                "sort": {
                    "openapi_types": (LogsSort,),
                    "attribute": "sort",
                    "location": "query",
                },
                "page_cursor": {
                    "openapi_types": (str,),
                    "attribute": "page[cursor]",
                    "location": "query",
                },
                "page_limit": {
                    "validation": {
                        "inclusive_maximum": 1000,
                    },
                    "openapi_types": (int,),
                    "attribute": "page[limit]",
                    "location": "query",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": [],
            },
            api_client=api_client,
        )

        self._submit_log_endpoint = _Endpoint(
            settings={
                "response_type": (dict,),
                "auth": ["apiKeyAuth"],
                "endpoint_path": "/api/v2/logs",
                "operation_id": "submit_log",
                "http_method": "POST",
                "version": "v2",
                "servers": [
                    {
                        "url": "https://{subdomain}.{site}",
                        "variables": {
                            "site": {
                                "description": "The regional site for customers.",
                                "default_value": "datadoghq.com",
                                "enum_values": [
                                    "datadoghq.com",
                                    "us3.datadoghq.com",
                                    "us5.datadoghq.com",
                                    "datadoghq.eu",
                                    "ddog-gov.com",
                                ],
                            },
                            "subdomain": {
                                "description": "The subdomain where the API is deployed.",
                                "default_value": "http-intake.logs",
                            },
                        },
                    },
                    {
                        "url": "{protocol}://{name}",
                        "variables": {
                            "name": {
                                "description": "Full site DNS name.",
                                "default_value": "http-intake.logs.datadoghq.com",
                            },
                            "protocol": {
                                "description": "The protocol for accessing the API.",
                                "default_value": "https",
                            },
                        },
                    },
                    {
                        "url": "https://{subdomain}.{site}",
                        "variables": {
                            "site": {
                                "description": "Any Datadog deployment.",
                                "default_value": "datadoghq.com",
                            },
                            "subdomain": {
                                "description": "The subdomain where the API is deployed.",
                                "default_value": "http-intake.logs",
                            },
                        },
                    },
                ],
            },
            params_map={
                "content_encoding": {
                    "openapi_types": (ContentEncoding,),
                    "attribute": "Content-Encoding",
                    "location": "header",
                },
                "ddtags": {
                    "openapi_types": (str,),
                    "attribute": "ddtags",
                    "location": "query",
                },
                "body": {
                    "required": True,
                    "openapi_types": (HTTPLog,),
                    "location": "body",
                    "collection_format": "multi",
                },
            },
            headers_map={
                "accept": ["application/json"],
                "content_type": ["application/json", "application/logplex-1", "text/plain"],
            },
            api_client=api_client,
        )

    def aggregate_logs(
        self,
        body: LogsAggregateRequest,
    ) -> LogsAggregateResponse:
        """Aggregate events.

        The API endpoint to aggregate events into buckets and compute metrics and timeseries.

        :type body: LogsAggregateRequest
        :rtype: LogsAggregateResponse
        """
        kwargs: Dict[str, Any] = {}
        kwargs["body"] = body

        return self._aggregate_logs_endpoint.call_with_http_info(**kwargs)

    def list_logs(
        self,
        *,
        body: Union[LogsListRequest, UnsetType] = unset,
    ) -> LogsListResponse:
        """Search logs.

        List endpoint returns logs that match a log search query.
        `Results are paginated </logs/guide/collect-multiple-logs-with-pagination>`_.

        Use this endpoint to build complex logs filtering and search.

        If you are considering archiving logs for your organization,
        consider use of the Datadog archive capabilities instead of the log list API.
        See `Datadog Logs Archive documentation <https://docs.datadoghq.com/logs/archives>`_.

        :type body: LogsListRequest, optional
        :rtype: LogsListResponse
        """
        kwargs: Dict[str, Any] = {}
        if body is not unset:
            kwargs["body"] = body

        return self._list_logs_endpoint.call_with_http_info(**kwargs)

    def list_logs_with_pagination(
        self,
        *,
        body: Union[LogsListRequest, UnsetType] = unset,
    ) -> collections.abc.Iterable[Log]:
        """Search logs.

        Provide a paginated version of :meth:`list_logs`, returning all items.

        :type body: LogsListRequest, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[Log]
        """
        kwargs: Dict[str, Any] = {}
        if body is not unset:
            kwargs["body"] = body

        local_page_size = get_attribute_from_path(kwargs, "body.page.limit", 10)
        endpoint = self._list_logs_endpoint
        set_attribute_from_path(kwargs, "body.page.limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "body.page.cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )

    def list_logs_get(
        self,
        *,
        filter_query: Union[str, UnsetType] = unset,
        filter_index: Union[str, UnsetType] = unset,
        filter_from: Union[datetime, UnsetType] = unset,
        filter_to: Union[datetime, UnsetType] = unset,
        filter_storage_tier: Union[LogsStorageTier, UnsetType] = unset,
        sort: Union[LogsSort, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
    ) -> LogsListResponse:
        """Get a list of logs.

        List endpoint returns logs that match a log search query.
        `Results are paginated </logs/guide/collect-multiple-logs-with-pagination>`_.

        Use this endpoint to see your latest logs.

        If you are considering archiving logs for your organization,
        consider use of the Datadog archive capabilities instead of the log list API.
        See `Datadog Logs Archive documentation <https://docs.datadoghq.com/logs/archives>`_.

        :param filter_query: Search query following logs syntax.
        :type filter_query: str, optional
        :param filter_index: For customers with multiple indexes, the indexes to search
            Defaults to '*' which means all indexes
        :type filter_index: str, optional
        :param filter_from: Minimum timestamp for requested logs.
        :type filter_from: datetime, optional
        :param filter_to: Maximum timestamp for requested logs.
        :type filter_to: datetime, optional
        :param filter_storage_tier: Specifies the storage type to be used
        :type filter_storage_tier: LogsStorageTier, optional
        :param sort: Order of logs in results.
        :type sort: LogsSort, optional
        :param page_cursor: List following results with a cursor provided in the previous query.
        :type page_cursor: str, optional
        :param page_limit: Maximum number of logs in the response.
        :type page_limit: int, optional
        :rtype: LogsListResponse
        """
        kwargs: Dict[str, Any] = {}
        if filter_query is not unset:
            kwargs["filter_query"] = filter_query

        if filter_index is not unset:
            kwargs["filter_index"] = filter_index

        if filter_from is not unset:
            kwargs["filter_from"] = filter_from

        if filter_to is not unset:
            kwargs["filter_to"] = filter_to

        if filter_storage_tier is not unset:
            kwargs["filter_storage_tier"] = filter_storage_tier

        if sort is not unset:
            kwargs["sort"] = sort

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        return self._list_logs_get_endpoint.call_with_http_info(**kwargs)

    def list_logs_get_with_pagination(
        self,
        *,
        filter_query: Union[str, UnsetType] = unset,
        filter_index: Union[str, UnsetType] = unset,
        filter_from: Union[datetime, UnsetType] = unset,
        filter_to: Union[datetime, UnsetType] = unset,
        filter_storage_tier: Union[LogsStorageTier, UnsetType] = unset,
        sort: Union[LogsSort, UnsetType] = unset,
        page_cursor: Union[str, UnsetType] = unset,
        page_limit: Union[int, UnsetType] = unset,
    ) -> collections.abc.Iterable[Log]:
        """Get a list of logs.

        Provide a paginated version of :meth:`list_logs_get`, returning all items.

        :param filter_query: Search query following logs syntax.
        :type filter_query: str, optional
        :param filter_index: For customers with multiple indexes, the indexes to search
            Defaults to '*' which means all indexes
        :type filter_index: str, optional
        :param filter_from: Minimum timestamp for requested logs.
        :type filter_from: datetime, optional
        :param filter_to: Maximum timestamp for requested logs.
        :type filter_to: datetime, optional
        :param filter_storage_tier: Specifies the storage type to be used
        :type filter_storage_tier: LogsStorageTier, optional
        :param sort: Order of logs in results.
        :type sort: LogsSort, optional
        :param page_cursor: List following results with a cursor provided in the previous query.
        :type page_cursor: str, optional
        :param page_limit: Maximum number of logs in the response.
        :type page_limit: int, optional

        :return: A generator of paginated results.
        :rtype: collections.abc.Iterable[Log]
        """
        kwargs: Dict[str, Any] = {}
        if filter_query is not unset:
            kwargs["filter_query"] = filter_query

        if filter_index is not unset:
            kwargs["filter_index"] = filter_index

        if filter_from is not unset:
            kwargs["filter_from"] = filter_from

        if filter_to is not unset:
            kwargs["filter_to"] = filter_to

        if filter_storage_tier is not unset:
            kwargs["filter_storage_tier"] = filter_storage_tier

        if sort is not unset:
            kwargs["sort"] = sort

        if page_cursor is not unset:
            kwargs["page_cursor"] = page_cursor

        if page_limit is not unset:
            kwargs["page_limit"] = page_limit

        local_page_size = get_attribute_from_path(kwargs, "page_limit", 10)
        endpoint = self._list_logs_get_endpoint
        set_attribute_from_path(kwargs, "page_limit", local_page_size, endpoint.params_map)
        while True:
            response = endpoint.call_with_http_info(**kwargs)
            for item in get_attribute_from_path(response, "data"):
                yield item
            if len(get_attribute_from_path(response, "data")) < local_page_size:
                break
            set_attribute_from_path(
                kwargs, "page_cursor", get_attribute_from_path(response, "meta.page.after"), endpoint.params_map
            )

    def submit_log(
        self,
        body: HTTPLog,
        *,
        content_encoding: Union[ContentEncoding, UnsetType] = unset,
        ddtags: Union[str, UnsetType] = unset,
    ) -> dict:
        """Send logs.

        Send your logs to your Datadog platform over HTTP. Limits per HTTP request are:

        * Maximum content size per payload (uncompressed): 5MB
        * Maximum size for a single log: 1MB
        * Maximum array size if sending multiple logs in an array: 1000 entries

        Any log exceeding 1MB is accepted and truncated by Datadog:

        * For a single log request, the API truncates the log at 1MB and returns a 2xx.
        * For a multi-logs request, the API processes all logs, truncates only logs larger than 1MB, and returns a 2xx.

        Datadog recommends sending your logs compressed.
        Add the ``Content-Encoding: gzip`` header to the request when sending compressed logs.

        The status codes answered by the HTTP API are:

        * 202: Accepted: the request has been accepted for processing
        * 400: Bad request (likely an issue in the payload formatting)
        * 401: Unauthorized (likely a missing API Key)
        * 403: Permission issue (likely using an invalid API Key)
        * 408: Request Timeout, request should be retried after some time
        * 413: Payload too large (batch is above 5MB uncompressed)
        * 429: Too Many Requests, request should be retried after some time
        * 500: Internal Server Error, the server encountered an unexpected condition that prevented it from fulfilling the request, request should be retried after some time
        * 503: Service Unavailable, the server is not ready to handle the request probably because it is overloaded, request should be retried after some time

        :param body: Log to send (JSON format).
        :type body: HTTPLog
        :param content_encoding: HTTP header used to compress the media-type.
        :type content_encoding: ContentEncoding, optional
        :param ddtags: Log tags can be passed as query parameters with ``text/plain`` content type.
        :type ddtags: str, optional
        :rtype: dict
        """
        kwargs: Dict[str, Any] = {}
        if content_encoding is not unset:
            kwargs["content_encoding"] = content_encoding

        if ddtags is not unset:
            kwargs["ddtags"] = ddtags

        kwargs["body"] = body

        return self._submit_log_endpoint.call_with_http_info(**kwargs)



"""
Create a notebook returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.notebooks_api import NotebooksApi
from datadog_api_client.v1.model.notebook_cell_create_request import NotebookCellCreateRequest
from datadog_api_client.v1.model.notebook_cell_resource_type import NotebookCellResourceType
from datadog_api_client.v1.model.notebook_create_data import NotebookCreateData
from datadog_api_client.v1.model.notebook_create_data_attributes import NotebookCreateDataAttributes
from datadog_api_client.v1.model.notebook_create_request import NotebookCreateRequest
from datadog_api_client.v1.model.notebook_graph_size import NotebookGraphSize
from datadog_api_client.v1.model.notebook_markdown_cell_attributes import NotebookMarkdownCellAttributes
from datadog_api_client.v1.model.notebook_markdown_cell_definition import NotebookMarkdownCellDefinition
from datadog_api_client.v1.model.notebook_markdown_cell_definition_type import NotebookMarkdownCellDefinitionType
from datadog_api_client.v1.model.notebook_relative_time import NotebookRelativeTime
from datadog_api_client.v1.model.notebook_resource_type import NotebookResourceType
from datadog_api_client.v1.model.notebook_split_by import NotebookSplitBy
from datadog_api_client.v1.model.notebook_status import NotebookStatus
from datadog_api_client.v1.model.notebook_timeseries_cell_attributes import NotebookTimeseriesCellAttributes
from datadog_api_client.v1.model.timeseries_widget_definition import TimeseriesWidgetDefinition
from datadog_api_client.v1.model.timeseries_widget_definition_type import TimeseriesWidgetDefinitionType
from datadog_api_client.v1.model.timeseries_widget_request import TimeseriesWidgetRequest
from datadog_api_client.v1.model.widget_axis import WidgetAxis
from datadog_api_client.v1.model.widget_display_type import WidgetDisplayType
from datadog_api_client.v1.model.widget_line_type import WidgetLineType
from datadog_api_client.v1.model.widget_line_width import WidgetLineWidth
from datadog_api_client.v1.model.widget_live_span import WidgetLiveSpan
from datadog_api_client.v1.model.widget_request_style import WidgetRequestStyle

body = NotebookCreateRequest(
    data=NotebookCreateData(
        attributes=NotebookCreateDataAttributes(
            cells=[
                NotebookCellCreateRequest(
                    attributes=NotebookMarkdownCellAttributes(
                        definition=NotebookMarkdownCellDefinition(
                            text="## Some test markdown\n\n```js\nvar x, y;\nx = 5;\ny = 6;\n```",
                            type=NotebookMarkdownCellDefinitionType.MARKDOWN,
                        ),
                    ),
                    type=NotebookCellResourceType.NOTEBOOK_CELLS,
                ),
                NotebookCellCreateRequest(
                    attributes=NotebookTimeseriesCellAttributes(
                        definition=TimeseriesWidgetDefinition(
                            requests=[
                                TimeseriesWidgetRequest(
                                    display_type=WidgetDisplayType.LINE,
                                    q="avg:system.load.1{*}",
                                    style=WidgetRequestStyle(
                                        line_type=WidgetLineType.SOLID,
                                        line_width=WidgetLineWidth.NORMAL,
                                        palette="dog_classic",
                                    ),
                                ),
                            ],
                            show_legend=True,
                            type=TimeseriesWidgetDefinitionType.TIMESERIES,
                            yaxis=WidgetAxis(
                                scale="linear",
                            ),
                        ),
                        graph_size=NotebookGraphSize.MEDIUM,
                        split_by=NotebookSplitBy(
                            keys=[],
                            tags=[],
                        ),
                        time=None,
                    ),
                    type=NotebookCellResourceType.NOTEBOOK_CELLS,
                ),
            ],
            name="Example-Create_a_notebook_returns_OK_response",
            status=NotebookStatus.PUBLISHED,
            time=NotebookRelativeTime(
                live_span=WidgetLiveSpan.PAST_ONE_HOUR,
            ),
        ),
        type=NotebookResourceType.NOTEBOOKS,
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = NotebooksApi(api_client)
    response = api_instance.create_notebook(body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import List, Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.widget_time_windows import WidgetTimeWindows
    from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
    from datadog_api_client.v1.model.slo_widget_definition_type import SLOWidgetDefinitionType
    from datadog_api_client.v1.model.widget_view_mode import WidgetViewMode


class SLOWidgetDefinition(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.widget_time_windows import WidgetTimeWindows
        from datadog_api_client.v1.model.widget_text_align import WidgetTextAlign
        from datadog_api_client.v1.model.slo_widget_definition_type import SLOWidgetDefinitionType
        from datadog_api_client.v1.model.widget_view_mode import WidgetViewMode

        return {
            "global_time_target": (str,),
            "show_error_budget": (bool,),
            "slo_id": (str,),
            "time_windows": ([WidgetTimeWindows],),
            "title": (str,),
            "title_align": (WidgetTextAlign,),
            "title_size": (str,),
            "type": (SLOWidgetDefinitionType,),
            "view_mode": (WidgetViewMode,),
            "view_type": (str,),
        }

    attribute_map = {
        "global_time_target": "global_time_target",
        "show_error_budget": "show_error_budget",
        "slo_id": "slo_id",
        "time_windows": "time_windows",
        "title": "title",
        "title_align": "title_align",
        "title_size": "title_size",
        "type": "type",
        "view_mode": "view_mode",
        "view_type": "view_type",
    }

    def __init__(
        self_,
        type: SLOWidgetDefinitionType,
        global_time_target: Union[str, UnsetType] = unset,
        show_error_budget: Union[bool, UnsetType] = unset,
        slo_id: Union[str, UnsetType] = unset,
        time_windows: Union[List[WidgetTimeWindows], UnsetType] = unset,
        title: Union[str, UnsetType] = unset,
        title_align: Union[WidgetTextAlign, UnsetType] = unset,
        title_size: Union[str, UnsetType] = unset,
        view_mode: Union[WidgetViewMode, UnsetType] = unset,
        **kwargs,
    ):
        """
        Use the SLO and uptime widget to track your SLOs (Service Level Objectives) and uptime on screenboards and timeboards.

        :param global_time_target: Defined global time target.
        :type global_time_target: str, optional

        :param show_error_budget: Defined error budget.
        :type show_error_budget: bool, optional

        :param slo_id: ID of the SLO displayed.
        :type slo_id: str, optional

        :param time_windows: Times being monitored.
        :type time_windows: [WidgetTimeWindows], optional

        :param title: Title of the widget.
        :type title: str, optional

        :param title_align: How to align the text on the widget.
        :type title_align: WidgetTextAlign, optional

        :param title_size: Size of the title.
        :type title_size: str, optional

        :param type: Type of the SLO widget.
        :type type: SLOWidgetDefinitionType

        :param view_mode: Define how you want the SLO to be displayed.
        :type view_mode: WidgetViewMode, optional

        :param view_type: Type of view displayed by the widget.
        :type view_type: str
        """
        if global_time_target is not unset:
            kwargs["global_time_target"] = global_time_target
        if show_error_budget is not unset:
            kwargs["show_error_budget"] = show_error_budget
        if slo_id is not unset:
            kwargs["slo_id"] = slo_id
        if time_windows is not unset:
            kwargs["time_windows"] = time_windows
        if title is not unset:
            kwargs["title"] = title
        if title_align is not unset:
            kwargs["title_align"] = title_align
        if title_size is not unset:
            kwargs["title_size"] = title_size
        if view_mode is not unset:
            kwargs["view_mode"] = view_mode
        super().__init__(kwargs)
        view_type = kwargs.get("view_type", "detail")

        self_.type = type
        self_.view_type = view_type



"""
Delete items from a dashboard list returns "OK" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.dashboard_lists_api import DashboardListsApi
from datadog_api_client.v2.model.dashboard_list_delete_items_request import DashboardListDeleteItemsRequest
from datadog_api_client.v2.model.dashboard_list_item_request import DashboardListItemRequest
from datadog_api_client.v2.model.dashboard_type import DashboardType

body = DashboardListDeleteItemsRequest(
    dashboards=[
        DashboardListItemRequest(
            id="q5j-nti-fv6",
            type=DashboardType.HOST_TIMEBOARD,
        ),
    ],
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = DashboardListsApi(api_client)
    response = api_instance.delete_dashboard_list_items(dashboard_list_id=9223372036854775807, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsTestMonitorStatus(ModelSimple):
    """
    The status of your Synthetic monitor.
        * `O` for not triggered
        * `1` for triggered
        * `2` for no data

    :param value: Must be one of [0, 1, 2].
    :type value: int
    """

    allowed_values = {
        0,
        1,
        2,
    }
    UNTRIGGERED: ClassVar["SyntheticsTestMonitorStatus"]
    TRIGGERED: ClassVar["SyntheticsTestMonitorStatus"]
    NO_DATA: ClassVar["SyntheticsTestMonitorStatus"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (int,),
        }


SyntheticsTestMonitorStatus.UNTRIGGERED = SyntheticsTestMonitorStatus(0)
SyntheticsTestMonitorStatus.TRIGGERED = SyntheticsTestMonitorStatus(1)
SyntheticsTestMonitorStatus.NO_DATA = SyntheticsTestMonitorStatus(2)



"""
Edit an API key returns "OK" response
"""

from os import environ
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.key_management_api import KeyManagementApi
from datadog_api_client.v2.model.api_key_update_attributes import APIKeyUpdateAttributes
from datadog_api_client.v2.model.api_key_update_data import APIKeyUpdateData
from datadog_api_client.v2.model.api_key_update_request import APIKeyUpdateRequest
from datadog_api_client.v2.model.api_keys_type import APIKeysType

# there is a valid "api_key" in the system
API_KEY_DATA_ID = environ["API_KEY_DATA_ID"]

body = APIKeyUpdateRequest(
    data=APIKeyUpdateData(
        type=APIKeysType.API_KEYS,
        id=API_KEY_DATA_ID,
        attributes=APIKeyUpdateAttributes(
            name="Example-Edit_an_API_key_returns_OK_response",
        ),
    ),
)

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = KeyManagementApi(api_client)
    response = api_instance.update_api_key(api_key_id=API_KEY_DATA_ID, body=body)

    print(response)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v1.model.scatterplot_table_request import ScatterplotTableRequest
    from datadog_api_client.v1.model.scatter_plot_request import ScatterPlotRequest


class ScatterPlotWidgetDefinitionRequests(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v1.model.scatterplot_table_request import ScatterplotTableRequest
        from datadog_api_client.v1.model.scatter_plot_request import ScatterPlotRequest

        return {
            "table": (ScatterplotTableRequest,),
            "x": (ScatterPlotRequest,),
            "y": (ScatterPlotRequest,),
        }

    attribute_map = {
        "table": "table",
        "x": "x",
        "y": "y",
    }

    def __init__(
        self_,
        table: Union[ScatterplotTableRequest, UnsetType] = unset,
        x: Union[ScatterPlotRequest, UnsetType] = unset,
        y: Union[ScatterPlotRequest, UnsetType] = unset,
        **kwargs,
    ):
        """
        Widget definition.

        :param table: Scatterplot request containing formulas and functions.
        :type table: ScatterplotTableRequest, optional

        :param x: Updated scatter plot.
        :type x: ScatterPlotRequest, optional

        :param y: Updated scatter plot.
        :type y: ScatterPlotRequest, optional
        """
        if table is not unset:
            kwargs["table"] = table
        if x is not unset:
            kwargs["x"] = x
        if y is not unset:
            kwargs["y"] = y
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations

from typing import Union, TYPE_CHECKING

from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
    unset,
    UnsetType,
)


if TYPE_CHECKING:
    from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import SensitiveDataScannerMetaVersionOnly


class SensitiveDataScannerGroupDeleteResponse(ModelNormal):
    @cached_property
    def openapi_types(_):
        from datadog_api_client.v2.model.sensitive_data_scanner_meta_version_only import (
            SensitiveDataScannerMetaVersionOnly,
        )

        return {
            "meta": (SensitiveDataScannerMetaVersionOnly,),
        }

    attribute_map = {
        "meta": "meta",
    }

    def __init__(self_, meta: Union[SensitiveDataScannerMetaVersionOnly, UnsetType] = unset, **kwargs):
        """
        Delete group response.

        :param meta: Meta payload containing information about the API.
        :type meta: SensitiveDataScannerMetaVersionOnly, optional
        """
        if meta is not unset:
            kwargs["meta"] = meta
        super().__init__(kwargs)



# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.
from __future__ import annotations


from datadog_api_client.model_utils import (
    ModelSimple,
    cached_property,
)

from typing import ClassVar


class SyntheticsAssertionOperator(ModelSimple):
    """
    Assertion operator to apply.

    :param value: Must be one of ["contains", "doesNotContain", "is", "isNot", "lessThan", "lessThanOrEqual", "moreThan", "moreThanOrEqual", "matches", "doesNotMatch", "validates", "isInMoreThan", "isInLessThan", "doesNotExist"].
    :type value: str
    """

    allowed_values = {
        "contains",
        "doesNotContain",
        "is",
        "isNot",
        "lessThan",
        "lessThanOrEqual",
        "moreThan",
        "moreThanOrEqual",
        "matches",
        "doesNotMatch",
        "validates",
        "isInMoreThan",
        "isInLessThan",
        "doesNotExist",
    }
    CONTAINS: ClassVar["SyntheticsAssertionOperator"]
    DOES_NOT_CONTAIN: ClassVar["SyntheticsAssertionOperator"]
    IS: ClassVar["SyntheticsAssertionOperator"]
    IS_NOT: ClassVar["SyntheticsAssertionOperator"]
    LESS_THAN: ClassVar["SyntheticsAssertionOperator"]
    LESS_THAN_OR_EQUAL: ClassVar["SyntheticsAssertionOperator"]
    MORE_THAN: ClassVar["SyntheticsAssertionOperator"]
    MORE_THAN_OR_EQUAL: ClassVar["SyntheticsAssertionOperator"]
    MATCHES: ClassVar["SyntheticsAssertionOperator"]
    DOES_NOT_MATCH: ClassVar["SyntheticsAssertionOperator"]
    VALIDATES: ClassVar["SyntheticsAssertionOperator"]
    IS_IN_MORE_DAYS_THAN: ClassVar["SyntheticsAssertionOperator"]
    IS_IN_LESS_DAYS_THAN: ClassVar["SyntheticsAssertionOperator"]
    DOES_NOT_EXIST: ClassVar["SyntheticsAssertionOperator"]

    @cached_property
    def openapi_types(_):
        return {
            "value": (str,),
        }


SyntheticsAssertionOperator.CONTAINS = SyntheticsAssertionOperator("contains")
SyntheticsAssertionOperator.DOES_NOT_CONTAIN = SyntheticsAssertionOperator("doesNotContain")
SyntheticsAssertionOperator.IS = SyntheticsAssertionOperator("is")
SyntheticsAssertionOperator.IS_NOT = SyntheticsAssertionOperator("isNot")
SyntheticsAssertionOperator.LESS_THAN = SyntheticsAssertionOperator("lessThan")
SyntheticsAssertionOperator.LESS_THAN_OR_EQUAL = SyntheticsAssertionOperator("lessThanOrEqual")
SyntheticsAssertionOperator.MORE_THAN = SyntheticsAssertionOperator("moreThan")
SyntheticsAssertionOperator.MORE_THAN_OR_EQUAL = SyntheticsAssertionOperator("moreThanOrEqual")
SyntheticsAssertionOperator.MATCHES = SyntheticsAssertionOperator("matches")
SyntheticsAssertionOperator.DOES_NOT_MATCH = SyntheticsAssertionOperator("doesNotMatch")
SyntheticsAssertionOperator.VALIDATES = SyntheticsAssertionOperator("validates")
SyntheticsAssertionOperator.IS_IN_MORE_DAYS_THAN = SyntheticsAssertionOperator("isInMoreThan")
SyntheticsAssertionOperator.IS_IN_LESS_DAYS_THAN = SyntheticsAssertionOperator("isInLessThan")
SyntheticsAssertionOperator.DOES_NOT_EXIST = SyntheticsAssertionOperator("doesNotExist")



"""
Delete a tag configuration returns "No Content" response
"""

from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v2.api.metrics_api import MetricsApi

configuration = Configuration()
with ApiClient(configuration) as api_client:
    api_instance = MetricsApi(api_client)
    api_instance.delete_tag_configuration(
        metric_name="ExampleDeleteatagconfigurationreturnsNoContentresponse",
    )
